<?php
class BdAdmin {

	var $options = array(
		'video'      => array(),
		'post_types' => array(),
	);

	function __construct($options = array())
	{
		$this->options = $options + $this->options;
		add_action('admin_init', array(&$this, 'init'));
		add_action('admin_menu', array(&$this, 'menu'));
		add_action('admin_notices', array(&$this, 'admin_notice'));
		add_action('admin_print_styles', array(&$this, 'admin_styles'));
		add_action('admin_enqueue_scripts', array(&$this, 'admin_script') );
		$this->video();
		
	}

	function init()
	{
		$this->metabox();
		$this->default_options();
		$this->activation();
	}

	/**
	* "Include file" function that checks if the "includes" directory and the required file exists before including it.
	* This function is mainly used to include the widgets and the in-built features from the "includes" folder of the theme
	* @param (string) $file : file name
	*/
	function include_file($file = null)
	{
		$inc_dir = '';
		
		if(is_dir(BD_THEME_DIR.'/includes'))
			$inc_dir = BD_THEME_DIR.'/includes';
		
		if(file_exists($inc_dir.'/'.$file)){
			return include_once $inc_dir.'/'.$file;
		}
	}


	function get_all_post_types()
	{
		$tab = array_keys($this->options['post-types']);
		array_push($tab, 'post', 'page');
		return $tab;
	}

	/**
	* We will use this function for SEO metaboxes
	* (framework/theme/bd-seo.php)
	*/
	function get_seo_post_types()
	{
		$tab = array_keys($this->options['post-types']);
		array_push($tab, 'post', 'page');

		$no_seo = array();

		foreach($this->options['post-types'] as $k => $v){
			if( isset( $v['seo'] ) && $v['seo'] == false ){
				array_push($no_seo, $k);
			}
		}
		$tab = array_diff($tab, $no_seo);
		return $tab;
	}


	/**
	* Add the Framework menu object to the WP admin menu
	*/
	function menu()
	{
		$icon = BD_FRAMEWORK_URL .'img/bd.png';

		add_object_page( __( BD_THEME_NAME, 'bd' ), __( BD_THEME_NAME, 'bd' ), 'administrator', 'bdframework', array(&$this, 'options'), '' );
		//add_submenu_page( 'bdframework','','','administrator','bdframework', array(&$this, 'options'));
		add_submenu_page( 'bdframework', __( 'Theme Options', 'bd' ), __( 'Theme Options', 'bd' ), 'administrator', 'bdframework', array(&$this, 'options') );

		// Update Theme page
		$menu_title = __( 'Theme Updates', 'bd' );
		if($xml = $this->get_theme_changelog()){
			if( version_compare( BD_THEME_VERSION, $xml->latest ) == -1 ){
				$menu_title = __( 'Theme Updates', 'bd').'<span class="update-plugins count-1"><span class="update-count">1</span></span>';
			}
		}

		add_submenu_page( 'bdframework', __( 'Theme Updates', 'bd' ), $menu_title, 'administrator', 'bdframework-update', array(&$this, 'update_page') );
		
		// Theme Collection page
		// We will enable this as soon as themes.brutaldesign.com/themes is ready ;)
		//add_submenu_page( 'bdframework', __( 'More Themes', 'bd' ), __( 'More Themes', 'bd' ), 'administrator', 'bdframework-themes', 'bd_themes_page' );
		
		// Support link/page
		add_submenu_page( 'bdframework', __( 'Support Forums', 'bd'), __('Support Forums', 'bd'), 'administrator', 'bdframework-support', array(&$this, 'support_page'));

	}

	/**
	* Enqueue admin Style (admin CSS)
	*/
	function admin_styles()
	{
		wp_enqueue_style("theme-admin", BD_FRAMEWORK_URL."css/theme-admin.css", false, "1.0", "all");
		wp_enqueue_style("colorpicker", BD_FRAMEWORK_URL."css/colorpicker/css/colorpicker.css", false, "1.0", "all");
		wp_enqueue_style("fonts", BD_THEME_URL."css/fonts.css", false, "1.0", "all");
	}


	/**
	 * Enqueue admin scripts (admin JS)
	 */
	function admin_script()
	{
		wp_register_script("tab-cookie", BD_FRAMEWORK_URL."js/cookie/jquery.memo.js",  'jquery',true, "1.0");
		wp_register_script("bd-colorpicker", BD_FRAMEWORK_URL."css/colorpicker/js/colorpicker.js", 'jquery', true, "1.0");
		wp_register_script("tipsy", BD_FRAMEWORK_URL."js/tipsy.js", 'jquery', true, "1.0.0");
		wp_register_script("admin", BD_FRAMEWORK_URL."js/admin.js", 'jquery', true, "1.0");
		wp_register_script("theme-options", BD_FRAMEWORK_URL."js/theme-options.js", 'jquery', true, "1.0");

		
		wp_enqueue_script("tipsy");
		wp_enqueue_script("admin");

		wp_enqueue_script("bd-colorpicker");
		
		

		if( isset( $_GET['page'] ) && $_GET['page'] == 'bdframework' ){
			wp_enqueue_script("tab-cookie");
			wp_enqueue_script("theme-options");
			
		}

		if( 
			isset( $_GET['page'] ) 
			&& $_GET['page'] == 'bd-sidebars.php' 
			&& !wp_script_is('jquery-ui-sortable')
		){
			wp_enqueue_script("jquery-ui-sortable");
		}

	}


	/**
	* Compare the theme version to the last update
	*/
	function get_theme_changelog()
	{

		$changelog_url = BD_UPDATE_URL . BD_THEME_SLUG .'/changelog.xml';
		$trans_key = 'bd_latest_theme_version_'. BD_THEME_SLUG;
		
		if ( false === ( $cached_xml = get_transient( $trans_key ) ) ){
			if( function_exists('curl_init') ){
				$ch = curl_init($changelog_url);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($ch, CURLOPT_HEADER, 0);
				curl_setopt($ch, CURLOPT_TIMEOUT, 10);
				$xml = curl_exec($ch);
				curl_close($ch);
			} else {
				$xml = file_get_contents($changelog_url);
			}
		
			if ($xml){
				set_transient( $trans_key, $xml, BD_CACHE_DURATION*6 ); 
			}
			
		} else {
			$xml = $cached_xml;
		}
		
		return @simplexml_load_string($xml);
	}


	/**
	 * Add an update or error notice to the dashboard when needed
	 *
	 */
	function admin_notice()
	{
		global $pagenow;

	    	/* Theme update
	    	--------------------------------------*/

		if( ($pagenow == 'index.php') && $xml = $this->get_theme_changelog() ){
			if( version_compare( BD_THEME_VERSION, $xml->latest ) == -1 ){
				?>
				<div id="message" class="updated">
					<p><strong><?php printf( __('There is a new version of %s available.', 'bd'),  BD_THEME_NAME); ?></strong>
						<?php printf( __('You have version %s installed.', 'bd'),  BD_THEME_VERSION ); ?>
						<a href="<?php echo esc_url(admin_url('admin.php?page=bdframework-update')); ?>"><?php printf( __('Update to version %s', 'bd'),  $xml->latest ); ?></a>
					</p>
				</div>
				<?php
			}
		}

		/* Error notice
	    	--------------------------------------------------------*/

	    	/* No cURL */
		$no_cURL = __('The <strong>cURL</strong> extension is not installed on your server.
		This extension is required for features that get data from external sources such as a twitter widget.
		 Please contact your hosting service for more informations.', 'bd');

		if( !function_exists('curl_init') ){
			bd_admin_notices( $no_cURL, 'error', true, 'no_cURL' );
		}
		

		/* No GD library */
		$no_GD_library = __('The <strong>GD library</strong> extension is not installed on your server. 
			This extension is essential to Wordpress to be able to resize your images. 
			Please contact your hosting service for more informations.', 'bd');


		if( !extension_loaded('gd') && !function_exists('gd_info') ) {
			bd_admin_notices( $no_GD_library, 'error', true, 'no_GD_library' );
		}

		
		/* Incorect Installation */
		$wrong_install = __('It seems that <strong>the theme has been installed incorrectly</strong>.
			Go <a href="http://wpwolf.com/common-wordpress-theme-issues/" target="_blank">here</a> for instructions.', 'bd');

		$bd_wp_themes_folder = basename(dirname(dirname(dirname(__FILE__))));

		if( $bd_wp_themes_folder != 'themes' ){
			bd_admin_notices( $wrong_install , 'error' );
		}


		return false;
	}


	/**
	* Support Page  :
	* Redirect to the support forum
	* http;//themes.brutaldesign.com/support
	*/
	function support_page()
	{
		require_once BD_FRAMEWORK_DIR.'/theme/bd-support-page.php';
	}

	/* Update Page */
	function update_page()
	{
		require_once BD_FRAMEWORK_DIR.'/theme/bd-update-page.php';
	}


	/**
	* Generate MetaBoxes : SEO, & custom metaboxes
	* We use the MetaBox class to do so (class/metabox.php)
	*/
	function metabox()
	{
		require_once BD_FRAMEWORK_DIR.'/class/metabox.php';
		$this->include_file('theme-metabox.php');
		require_once BD_FRAMEWORK_DIR.'/theme/bd-custom-background.php';
		require_once BD_FRAMEWORK_DIR.'/seo/bd-seo-metaboxes.php';
	}


	/**
	* Theme Options
	* Generate Theme Options page with the BdThemeOptions class
	* The theme options are set in "includes/theme-options.php"
	*/
	function options()
	{
		/* Theme Options class */
		require_once BD_FRAMEWORK_DIR.'/class/options.php';
		/* Theme Options */
		$this->include_file('theme-options.php');
		
	}

	/* Theme Default Options*/
	function default_options()
	{
		$this->include_file('theme-default-options.php');
	}


	/**
	* Video Post Field and Video Thumbnail Generator
	*/
	function video()
	{
		require_once BD_FRAMEWORK_DIR.'/class/video.php'; //Video Thumbnails
		$video = new BDVideo($this->options['video']);
		require_once BD_FRAMEWORK_DIR.'/helper/video-thumbnails.php'; //Video Thumbnails
	}

	/**
	* Activation
	* Set default WP options & default pages
	*/
	function activation()
	{
		if ( isset($_GET['activated']) ){
			$this->include_file('activation/theme-default-pages.php');	
			$this->include_file('activation/theme-default-wp-options.php');	
		}
	}

}
?>