<?php
/*-----------------------------------------------------------------------------------*/
/*
/*	BrutalDesign Framework v1.2.4.2
/*
/*-----------------------------------------------------------------------------------*/

class BdTheme {
	
	/* Theme default settings */
	var $options = array(
		'width' => '620',
		'menus' => array('primary' => 'Main Menu'),
		'post-types' => array(),
		'taxonomy' => array(),
		'widgets' => array(),
		'post-formats' => array('gallery', 'image', 'aside', 'video', 'audio', 'link', 'quote'),
		'images' => array(),
		'features' => array(),
		'video' => array(),	
	);
	
	function __construct($options = array())
	{
		$this->options = $options + $this->options;

		require_once 'bd-config.php';
		require_once 'bd-settings.php';
		
		$this->init();


		/**
		* Set all the WP features
		* Print Styles and Enqueue Scripts
		*/
		add_action( 'after_setup_theme', array(&$this, 'after_setup') );
		add_action( 'wp_enqueue_scripts', array( &$this, 'add_styles') ) ;
		add_action( 'wp_enqueue_scripts', array( &$this, 'add_scripts' ) );
		
			
	}

	/**
	* Init function
	*/
	function init() 
	{    
		$this->functions();
		$this->types();
		$this->widgets();
		$this->features();
		$this->sidebar_plugin();
		$this->sidebars();
		$this->menus();
		$this->seo();
		$this->shortcodes();
		$this->admin();
		$this->render_options();
	}


	/**
	* First basic wordpress components
	*/
	function after_setup()
	{
		$this->language(); 
		$this->supports(); 
		$this->images();
		$this->postformats();
	}



	/**
	* "Include file" function that checks if the "includes" directory and the required file exists before including it.
	* This function is mainly used to include the widgets and the in-built features from the "includes" folder of the theme
	* @param (string) $file : file name
	*/
	function include_file($file = null)
	{
		$inc_dir = '';
		
		if(is_dir(BD_THEME_DIR.'/includes'))
			$inc_dir = BD_THEME_DIR.'/includes';
		
		if(file_exists($inc_dir.'/'.$file)){
			return include_once $inc_dir.'/'.$file;
		}
	}


	/**
	* Default WP supports
	* Custom background, post thumbnails, RSS and editor style
	*/
	function supports()
	{
		if (function_exists('add_theme_support')) {
			add_theme_support('post-thumbnails');
			add_theme_support('automatic-feed-links');
			add_theme_support('editor-style');
		}

		if (
			function_exists('add_editor_style')
			&& is_file( BD_THEME_DIR . '/css/custom-editor-style.css' )
		) {
			add_editor_style( 'css/custom-editor-style.css' );
		}
	}

	/**
	* Register menus
	*/
	function menus()
	{
		if ( function_exists( 'register_nav_menus' ) ) {
		            register_nav_menus($this->options['menus']);
	             }
	}

	/**
	* Set the different thumbnail sizes needed in the design
	* (set in functions.php)
	*/
	function images()
	{	
		global $content_width;
		set_post_thumbnail_size( $content_width, $content_width/2 ); // default Post Thumbnail dimensions   	
		
		if( $this->options['images'] != array()){
			if ( function_exists( 'add_image_size' ) ) { 
				foreach($this->options['images'] as $k => $v){
					add_image_size( $k, $v[0], $v[1], $v[2]);
				}			
			}
		}
	}

	/**
	* Sidebars : 
	* Set theme default Sidebars (usually blog sidebar and footer widget area)
	*/
	function sidebars()
	{
		$this->include_file('theme-sidebars.php');
	}

	/**
	* Require the sidebar manager included in the framework.
	* The plugin create a sidebar for each post types if they exists and aren't full width  style
	* (like portfolio, galleries etc.. a function can override this in "includes/theme-functions.php" : bd_post-types_sidebars())
	* Allow the user to create unlimited sidebars
	* Add metabox to choose wich sidebar to display on each page, in the page editor
	*/
	function sidebar_plugin()
	{
		require_once BD_FRAMEWORK_DIR.'/sidebars/bd-sidebars.php'; //Sidebars plugin
	}


	/**
	* features :
	* Include in-built features from "includes/features" folder
	*/
	function features()
	{
		if( $this->options['features'] != array()){
			 foreach($this->options['features'] as $feature){
			 	$this->include_file('features/bd-'.$feature.'/bd-'.$feature.'.php');
			}
		}
	}	

	/**
	* Post Formats : 
	* Include CF Post Formats Plugin
	* The plugin customize the text editor for post format feature.
	* Add tabs and custom metaboxes to the post text editor
	* @author crowdfavorite - http://crowdfavorite.com/
	*/
	function postformats()
	{
		if( $this->options['post-formats'] != array()){
			add_theme_support( 'post-formats', $this->options['post-formats'] );
			require_once BD_FRAMEWORK_DIR.'/post-format/cf-post-formats.php'; //Post format plugin 
		}
	}

	/**
	* Post Types : 
	* Register Post Types and Taxonomy
	* We use the "BdPostTypes" class to generate them
	* (framework/class/post-types.php)
	*/
	function types()
	{
		if( $this->options['post-types'] != array()){
			require_once BD_FRAMEWORK_DIR.'/class/post-types.php';
			$types = new BdPostTypes($this->options['post-types'], $this->options['taxonomy']);
		}
	}

	/**
	* Widgets : 
	* Includes all widgets
	* ("includes/widgets" folder)
	*/
	function widgets()
	{
		if( $this->options['widgets'] != array()){
			foreach($this->options['widgets'] as $w){
				$this->include_file('widgets/'.$w.'-widget.php');
			}
		}
	}
	
		
	/**
	* Import framework filters, functions and specific theme-options &  theme-template-tags
	*/
	function functions()
	{
		require_once BD_FRAMEWORK_DIR.'/theme/bd-filters.php'; 
		require_once BD_FRAMEWORK_DIR.'/theme/bd-admin-functions.php';
		require_once BD_FRAMEWORK_DIR.'/theme/bd-functions.php';
		$this->include_file('theme-functions.php'); // Functions specific to the theme
		$this->include_file('theme-template-tags.php'); // Functions specific to the theme
	}


	/**
	* SEO feature included in the framework
	*/
	function seo()
	{
		require_once BD_FRAMEWORK_DIR.'/seo/bd-seo.php'; // Filter action and other options
	}


	/**
	* Basic shortcodes included in the framework
	*/
	function shortcodes()
	{
		require_once BD_FRAMEWORK_DIR.'/shortcodes/bd-shortcodes.php';
	}


	/**
	* Render Theme Options Styles to Front end
	*/
	function render_options()
	{
		$this->include_file('theme-options-css.php');
	}


	/**
	* Register & Print  Styles (includes/theme-styles.php)
	*/
	function add_styles(){
		$this->include_file('theme-styles.php');
	}

	/**
	* Register & Enqueue  Scripts (includes/theme-scripts.php)
	*/
	function add_scripts()
	{
		$this->include_file('theme-scripts.php');
	}

	/**
	* Language Support : 
	* Check .po and .mo files in "languages" folder
	*/
	function language()
	{
		load_theme_textdomain( 'bd', BD_THEME_DIR . '/languages' );
        
	             $locale = get_locale();
	    	$locale_file = BD_THEME_DIR . "/languages/$locale.php";
	    	if ( is_readable( $locale_file ) )
	    		require_once( $locale_file );
	}

	/**
	* Admin Set Up
	* See "bd-admin.php"
	*/
	function admin()
	{
		if(is_admin()){
			require_once BD_FRAMEWORK_DIR.'/bd-admin.php';
			$bd_admin_theme = new BdAdmin(array(
				'video' => $this->options['video'], 
				'post-types' => $this->options['post-types'])
			);	
		}
	}

}
?>
