<?php
class BdThemeOptions {

	var $options = array();

	function __construct($options = array())
	{
		$this->options = $options + $this->options;
		$this->options_init();
		$this->save();
		$this->render();
	}

	/**
	* Default theme options are defined in "includes/theme-default-optons.php"
	*/
	function options_init()
	{

		if( function_exists('bd_theme_default_options_init') )
			bd_theme_default_options_init();

				
	}


	/**
	* Get bd_theme_options values
	*/
	function get_theme_option($value = null)
	{
		global $options;

		$theme_options = get_option('bd_theme_options');
		if( isset($theme_options[$value]) )
			return $theme_options[$value];
		else
			return null;
	}

	/**
	* Save the theme options as array 
	*/
	function save()
	{
		global $options;
		

		$img_dir = BD_UPLOAD_DIR;

		if ( (isset($_GET['page'])) && ($_GET['page'] == 'bdframework')  ) {
			
			$errors = array();
			
			if ( isset($_POST['action']) && $_POST['action'] == 'save' && wp_verify_nonce($_POST['bd_save_theme_options_nonce'],'bd_save_theme_options') ) {

				$new_options = array();
				$data = $_POST['bd_theme_options'];
				
				foreach ($this->options as $value) {
					
					if( $value['type'] == 'int' ){

						$new_options[$value['id']] = intval($data[$value['id']]);
							
					}

					elseif( $value['type'] == 'email' ){

						if( !empty($data[$value['id']]) && !is_email( $_POST['bd_theme_options'][$value['id']] ) ){

							$errors[] = '<strong>'.$data[$value['id']].'</strong> '.__('is not a valid email', 'bd').'.';

						}elseif( !empty($data[$value['id']]) ){

							$new_options[$value['id']] = sanitize_email($data[$value['id']]);

						}


					}

					elseif( $value['type'] == 'textarea' || $value['type'] == 'javascript' ){
						if( !empty( $data[$value['id']] ) ){

							$new_options[$value['id']] = $data[$value['id']] ;

						}
					}

					elseif( $value['type'] == 'font-title' ){

						$new_options[$value['id']] = $data[$value['id']] ;

						$new_options[$value['id'].'_transform'] = $data[$value['id'].'_transform'] ;

					}

					
					elseif( $value['type'] == 'file' ||  $value['type'] == 'background' ){


						if($value['type'] == 'background'){

							$bg_settings = array('color', 'position', 'repeat', 'attachment');

							foreach( $bg_settings as $s ){

								$o = $value['id'].'_'.$s;
								
								//debug($data[ $value['id'].'_'.$s ] );
								
								if( isset( $o ) && !empty( $data[ $o ] ) ){

									$new_options[$o] = sanitize_text_field( $data[ $o ] );

								}

							}

							$id = $value['id'].'_img';

						}

						elseif( $value['type'] =='file' )
							$id = $value['id'];
						
						if(!empty($_FILES[ $id ]['name'])){
							
							$tmp = $_FILES[ $id ]['tmp_name'];
							$ext = pathinfo($_FILES[ $id ]['name'], PATHINFO_EXTENSION); 
							$img_name =$id.'_'.$_FILES[ $id ]['name'];
							$img_name = wp_unique_filename($img_dir, $img_name);
							$allowed_types = array('image/jpg', 'image/jpeg', 'image/gif', 'image/png');
							if(in_array($_FILES[ $id ]['type'], $allowed_types)){
								
								/* delete old file */
								bd_delete_file( $img_dir.'/'.$this->get_theme_option( $id ) );
					
								/* upload the new file */
								move_uploaded_file($tmp, $img_dir.'/'.$img_name);
								
								$new_options[ $id ] = $img_name;

							}else{
								$errors[] = '<strong>'.$_FILES[ $id ]['name'].'</strong> '.__('does not have a valid extension. Only jpg, png and gif are allowed', 'bd').'.';
							}


						}elseif($_POST[$id.'_set'] == ""){

							bd_delete_file( $img_dir.'/'.$this->get_theme_option( $id ) );

						}else{
							if($this->get_theme_option( $id ) )
								$new_options[$id] = $this->get_theme_option( $id ) ; 
						}

					}else{
						if(isset($value['id']) && !empty($data[$value['id']])){
							$new_options[$value['id']] = sanitize_text_field( strip_tags( $data[$value['id']] )) ;
						}
						

					}


				}

				
				//debug($new_options);
				update_option('bd_theme_options', $new_options);				

		 
			}else if( (isset($_POST['action'])) && ($_POST['action'] == 'reset') ) {
			 	
			 	$old_options = get_option('bd_theme_options');
			 	
			 	if($old_options){
			 		foreach($old_options as $option){
			 			if(is_file($img_dir.'/'.$option))
							unlink($img_dir.'/'.$option);
			 		}
			 	}

				delete_option('bd_theme_options');

				if( function_exists('bd_theme_default_options_init') )
					bd_theme_default_options_init();
				
			}

			if ( (isset($_POST['action'])) && ($_POST['action']=="save") ) 
				echo '<br><div id="message" class="updated fade"><p><strong>'.__('Settings saved', 'bd').'.</strong></p>
			</div>';
			if ( (isset($_POST['action'])) && ($_POST['action']=="reset") ) 
				echo '<br><div id="message" class="updated fade"><p><strong>'.__('Settings reset', 'bd').'.</strong></p></div>';

				
			/* Display error message */

			if($errors != array() ){
				$error_message = '<br><div class="error">';
				foreach($errors as $error){
					$error_message .= '<p>'.$error.'</p>';
				}
				$error_message .= '</div>';
				echo $error_message;
			}
		

		}

		
	
	} // end save function

	/**
	* Compare the theme version to the last update
	*/
	function get_theme_changelog()
	{

		$changelog_url = BD_UPDATE_URL . BD_THEME_SLUG .'/changelog.xml';
		$trans_key = 'bd_latest_theme_version_'. BD_THEME_SLUG;
		
		if ( false === ( $cached_xml = get_transient( $trans_key ) ) ){
			if( function_exists('curl_init') ){
				$ch = curl_init($changelog_url);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($ch, CURLOPT_HEADER, 0);
				curl_setopt($ch, CURLOPT_TIMEOUT, 10);
				$xml = curl_exec($ch);
				curl_close($ch);
			} else {
				$xml = file_get_contents($changelog_url);
			}
		
			if ($xml){
				set_transient( $trans_key, $xml, BD_CACHE_DURATION*6 ); 
			}
			
		} else {
			$xml = $cached_xml;
		}
		
		return @simplexml_load_string($xml);
	}

	
	/* *
	* Show Theme Options inputs
	**/
	function render()
	{

	$i = 0; $j = 0; $k = 0; $y = 0;
	 
	//uncomment the line below the debug theme saved options
	//debug(get_option('bd_theme_options'));
	
	?>
	<div class="clear"></div>
	<div id="framework-messages">
	        <?php if(isset($_GET['activated'])){ ?>
	        <div class="updated" id="message"><p><?php printf( __('%s activated', 'bd'),  BD_THEME_NAME ); ?></p></div>
	        <?php } ?>
	        <?php 
	        	/**
	        	* Check for theme update and set an admin notification if needed
	        	*/
		if($xml = $this->get_theme_changelog()){
			if( version_compare( BD_THEME_VERSION, $xml->latest ) == -1 ){
				?>
				<div id="message" class="updated">
					<p><strong><?php printf( __('There is a new version of %s available.', 'bd'),  BD_THEME_NAME); ?></strong>
						<?php printf( __('You have version %s installed.', 'bd'),  BD_THEME_VERSION ); ?>
						<a href="<?php echo esc_url(admin_url('admin.php?page=bdframework-update')); ?>"><?php printf( __('Update to version %s', 'bd'),  $xml->latest ); ?></a>
					</p>
				</div>
				<?php 
			}
		}
		?>
	</div>
	<form id="theme_options_form" enctype="multipart/form-data" method="post" action="<?php echo esc_url(admin_url('admin.php?page=bdframework')); ?>">
	<?php wp_nonce_field('bd_save_theme_options', 'bd_save_theme_options_nonce'); ?>
	<div class="bloc">

		<div class="title">
			<h1><?php echo BD_THEME_NAME; ?> <small>v.<?php echo BD_THEME_VERSION; ?></small></h1>
			<div class="tabs" id="tabs1" >
				<?php foreach ($this->options as $value) { ?>
					<?php if($value['type']=='section'){ ?>
					<?php $y++; ?>
					<a href="#panel<?php echo $y; ?>" class=""><?php echo $value['name']; ?></a>
				<?php } }?>
			</div>
		</div>

	<div class="content">

<?php foreach ($this->options as $value) {
	if(!isset($value['def'])) $value['def'] = '';
	if(!isset($value['desc'])) $value['desc'] = '';
	
	if($value['type']=='open'){
	$k++;
	?>
	<div id="panel<?php echo $k; ?>">

	<?php 
	}elseif($value['type']=='close'){
	?>	
	</div>

	<?php 
	}elseif($value['type']=='section'){
	?>

		<div class="bd_title_actions">	
		<p><?php echo $value['desc']; ?></p>	
			<script type="text/javascript">
			jQuery(function($){
				$('.bd-theme-options-save').click(function(){
					$(this).prev('.bd-options-loader').show();
				});
			});
			</script>
			<span class="submit">
				<img class="bd-options-loader" style="display:none; vertical-align:middle; margin-right:5px" src="<?php echo admin_url('images/loading.gif'); ?>" alt="loader">
				<input name="bd-theme-options-save" type="submit" class="bd-theme-options-save button-primary menu-save" value="<?php _e('Save changes', 'bd'); ?>">
				<div style="float:none; clear:both"></div>
			</span>
			<div class="clear"></div>
		</div>

	<?php 

	}elseif($value['type']=='subtitle'){
	?>

		<div class="bd_title">
			<h3>
			<?php echo $value['name']; ?>
			</h3>

			<div class="clear"></div>
		</div>

	<?php 
	}else{

			$this->do_input($value);

			}
	// foreach $options
	}
	?>
	 
	<input type="hidden" name="action" value="save">
	</form>



	<!--endcontent-->
	</div> 

	<!--endbloc-->
	</div>
	<form method="post" action="<?php echo admin_url('admin.php?page=bdframework'); ?>">
	<!-- 
	Soon, the BrutalDesign FrameWork will use AJAX to save theme options
	<form action="<?php //echo site_url() .'/wp-admin/admin-ajax.php'; ?>" method="post"> -->
		<p class="submit">
		<input name="reset" type="submit" value="Reset all options" onclick="if (window.confirm('Are you sure to want to reset all options ?')) 
		{location.href='default.htm';return true;} else {return false;}">
		<input type="hidden" name="action" value="reset">
		</p>
	</form>
	<?php
		if(BD_DEBUG){
			echo "<br><br>options";
			debug(get_option('bd_theme_options'));

			echo "<br><br>posted";
			debug($_POST);

			echo "<br><br>posted files";
			debug($_FILES);
			
			
		}
		//end bd_options_admin
	}


/**
* Generate theme option inputs
* @return string
*/
function do_input($item)
{
	$prefix = 'bd_theme_options';
	$type = 'text';
	$desc = '';
	$def = '';
	$pre = '';
	$app = '';
	
	if( isset($item['type']) ) $type = $item['type'];
	if( isset($item['def']) ) $def = $item['def'];
	if( isset($item['desc']) ) $desc= $item['desc'];
	if( isset($item['pre']) ) $pre= $item['pre'];
	if( isset($item['app']) ) $app= $item['app'];

	if( $type == 'text' || $type == 'int' || $type == 'email' || $type == 'url'): ?>

		<div class="bd_input bd_text">

			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?>
				<br>
				<small><?php echo $desc; ?></small>
			</label>

			<div class="<?php if( $pre != '' ): echo "input-prepend"; elseif($app!=''): echo "input-append"; endif;?>">
			<?php if($pre != ''): ?>
				<span class="add-on"><?php echo $pre; ?></span>
			<?php endif; ?>
				<input name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>" type="text" value="<?php echo ( bd_get_option($item['id']) ) ? stripslashes( bd_get_option($item['id']) ) : $def; ?>">
			<?php if($app != ''): ?>
				<span class="add-on"><?php echo $app; ?></span>
			<?php endif; ?>
			</div>
			<div class="clear"></div>

		</div>

	<?php elseif( $type == 'css' ): ?>

	<div id="custom_css_container">
                <div name="custom_css" id="bd_theme_options[custom_css]" style="border: 1px solid #DFDFDF; -moz-border-radius: 3px; -webkit-border-radius: 3px; border-radius: 3px; width: 100%; height: 400px; position: relative;"></div>
            </div>
 
            <textarea id="custom_css_textarea" name="bd_theme_options[custom_css]" style="display: none;"><?php echo ( bd_get_option($item['id']) ) ? stripslashes( bd_get_option($item['id']) ) : $def; ?></textarea>

    	<?php elseif( $type == 'textarea' || $type == 'javascript' ): ?>

	    	<div class="bd_input bd_textarea">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?><br>
			<small><?php echo $desc; ?></small></label>
			<textarea name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo ( bd_get_option($item['id']) ) ? stripslashes( bd_get_option($item['id']) ) : $def; ?></textarea>
			<div class="clear"></div>
		 </div>

    	<?php elseif( $type == 'select' ): ?>


	    	<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?><br>
				<small><?php echo $desc; ?></small>
			</label>
			
		<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>">
				<?php if(array_keys($item['options']) != array_keys(array_keys($item['options']))): ?>
					<?php foreach ($item['options'] as $v => $o) { ?>
						<option value="<?php echo $v; ?>" <?php if ( stripslashes(bd_get_option($item['id'])) == $v  ) { echo 'selected="selected"'; } ?>><?php echo $o; ?></option>
					<?php } ?>
				<?php else: ?>
					<?php foreach ($item['options'] as $v) { ?>
						<option value="<?php echo $v; ?>" <?php if ( stripslashes(bd_get_option($item['id'])) == $v  ) { echo 'selected="selected"'; } ?>><?php echo $v; ?></option>
					<?php } ?>
				<?php endif; ?>
		</select>

			<div class="clear"></div>
		</div>

	<?php elseif( $type == 'checkbox' ): ?>

		<?php
		$checked = "";
		if( bd_get_option($item['id']) == 'true' ) $checked = "checked=\"checked\""; 
		if( bd_get_option($item['id']) == 'false' ) $checked = ""; 
		?>
		
		<div class="bd_input bd_checkbox">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?>
				<br><small><?php echo $desc; ?></small>
			</label>
			<input type="checkbox" name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>" value="true" <?php echo $checked; ?>>

			<div class="clear"></div>
		 </div>

	<?php elseif( $type == 'radio' ): ?>


		<div class="bd_input bd_checkbox">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?></label>
			<?php if($def==true){ $checked = "checked=\"checked\""; }else{ $checked = "";} ?>
			<input type="radio" name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>" value="true" <?php echo $checked; ?>>
			<small><?php echo $desc; ?></small><div class="clear"></div>
		 </div>


	<?php elseif( $type == 'file' ): ?>

		<div class="bd_input bd_text">

			<label for="<?php echo $item['id']; ?>"><?php echo $item['name']; ?>
				<br><small><?php echo $desc; ?></small>
			</label>
			
		 	<input name="<?php echo $item['id']; ?>" id="<?php echo $item['id']; ?>" type="file">
		 	<input type="hidden" name="<?php echo $item['id']; ?>_set" value="<?php if ( bd_get_option($item['id']) ) echo "set"; ?>"><a href="#" class="reset">reset</a>
		 	

			<?php if ( bd_get_option($item['id']) ): ?>
			<div style="float:left; margin-right:15px; width:80px; min-height:10px" class="file-preview">
				<img src="<?php echo BD_UPLOAD_URL.bd_get_option($item['id']); ?>?<?php echo time(); ?>" alt="<?php echo $item['id']; ?>" width="80">
			</div>
			<?php endif; ?>
			
		 	
		 	<div class="clear"></div>
		 
		 </div>

	<?php elseif( $type == 'background' ): ?>
		<div class="bd_title">
			<h3>
			<?php echo $item['name']; ?>
			<br><small><?php echo $desc; ?></small>
			</h3>
			<div class="clear"></div>
		</div>
	<?php
	/* Color
	---------------*/
	?>
		<style type="text/css">
			#colorSelector<?php echo $item['id']; ?>_color {
					position: relative;
					margin-top:8px;
					width: 36px;
					height: 36px;
					float:left;
					background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png);
				}

			#colorSelector<?php echo $item['id']; ?>_color div {
				position: absolute;
				top: 3px;
				left: 3px;
				width: 30px;
				height: 30px;
				background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png) center;
				border-radius:5px; -moz-border-radius:5px; -o-border-radius:5px; -webkit-border-radius:5px;
				-ms-border-radius: 5px;-khtml-border-radius: 5px;
				cursor:pointer;
			}
		</style>
		<script type="text/javascript">
			jQuery(document).ready(function($){
			$('#colorSelector<?php echo $item['id']; ?>_color').ColorPicker({
					color: '<?php if ( bd_get_option($item['id'].'_color') ) echo htmlentities( stripslashes(bd_get_option($item['id'].'_color') ) ); ?>',
					onShow: function (colpkr) {
						$(colpkr).fadeIn(500);
						return false;
					},
					onHide: function (colpkr) {
						$(colpkr).fadeOut(500);
						return false;
					},
					onChange: function (hsb, hex, rgb) {
						$('#colorSelector<?php echo $item['id']; ?>_color div').css('backgroundColor', '#' + hex);
						$("#<?php echo $item['id']; ?>_color").val('#'+hex);
					}
				});
		});
		</script>
		<div class="bd_input bd_text">
			
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_color]"><?php echo $item['name']; ?>  <?php _e('Color', 'bd'); ?><br>
			</label>
			<div id="colorSelector<?php echo $item['id']; ?>_color">
				<div style="background-color:<?php if ( bd_get_option($item['id'].'_color') ) echo htmlentities( stripslashes(bd_get_option($item['id'].'_color') ) ); ?>">
				</div>
			</div>
		 	<input name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_color]" id="<?php echo $item['id']; ?>_color" style="width:75px" type="text" value="<?php if ( bd_get_option($item['id'].'_color') ) echo htmlentities( stripslashes(bd_get_option($item['id'].'_color') ) ); ?>">
		 	<a href="#" class="reset">reset</a>
		 	<div class="clear"></div>
		 
		</div>
	<?php
	/* Image
	---------------*/
	?>
		<div class="bd_input bd_text">

			<label for="<?php echo $item['id']; ?>_img"><?php echo $item['name']; ?>  <?php _e('Image', 'bd'); ?>
			</label>
			
		 	<input name="<?php echo $item['id']; ?>_img" id="<?php echo $item['id']; ?>_img" type="file">
		 	<input type="hidden" name="<?php echo $item['id']; ?>_img_set" value="<?php if ( bd_get_option($item['id'].'_img') ) echo "set"; ?>"><a href="#" class="reset">reset</a>
		 	

			<?php if ( bd_get_option($item['id'].'_img') ): ?>
			<div style="float:left; margin-right:15px; width:80px; min-height:10px" class="file-preview">
				<img src="<?php echo BD_UPLOAD_URL.bd_get_option($item['id'].'_img'); ?>?<?php echo time(); ?>" alt="<?php echo $item['id']; ?>_img" width="80">
			</div>
			<?php endif; ?>
			
		 	
		 	<div class="clear"></div>
		 
		 </div>
	<?php
	/* Repeat
	---------------*/
	?>
	<?php 
	$options = array( 'repeat', 'no-repeat', 'repeat-x', 'repeat-y' );
	 ?>
		<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_repeat]"><?php echo $item['name']; ?>  <?php _e('Repeat', 'bd'); ?></label>
				
			<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_repeat]" id="<?php echo $item['id']; ?>_repeat">
				<?php foreach ($options as $o): ?>
					<option value="<?php echo $o; ?>" <?php if ( stripslashes(bd_get_option($item['id'].'_repeat')) == $o  ) echo 'selected="selected"'; ?>><?php echo $o; ?></option>
				<?php endforeach; ?>
			</select>

			<div class="clear"></div>
		</div>

	<?php
	/* Position
	---------------*/
	
	$options = array( 
		'center top', 
		'left top' ,
		'right top' , 
		'center bottom', 
		'left bottom' , 
		'right bottom' ,
		'center center' ,
		'left center' ,
		'right center'
	);
	 ?>
		<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_position]"><?php echo $item['name']; ?>  <?php _e('Position', 'bd'); ?></label>
				
			<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_position]" id="<?php echo $item['id']; ?>_position">
				<?php foreach ($options as $o): ?>
					<option value="<?php echo $o; ?>" <?php if ( stripslashes(bd_get_option($item['id'].'_position')) == $o  ) echo 'selected="selected"'; ?>><?php echo $o; ?></option>
				<?php endforeach; ?>
			</select>

			<div class="clear"></div>
		</div>
	<?php
	/* Attachment
	---------------*/
	$options = array( 'scroll', 'fixed'); 

	?>
		<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_attachment]"><?php echo $item['name']; ?>  <?php _e('Attachment', 'bd'); ?></label>
				
			<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_attachment]" id="<?php echo $item['id']; ?>_attachment">
				<?php foreach ($options as $o): ?>
					<option value="<?php echo $o; ?>" <?php if ( stripslashes(bd_get_option($item['id'].'_attachment')) == $o  ) echo 'selected="selected"'; ?>><?php echo $o; ?></option>
				<?php endforeach; ?>
			</select>

			<div class="clear"></div>
		</div>

	<?php
	/* Font
	---------------*/
	?>

	<?php elseif( $type == 'font-title' ): ?>

		<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?> transform
				<br><small></small>
			</label>
			<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>_transform]" id="<?php echo $item['id']; ?>_transform" class="bd_font_select_transform">
				<option value="normal" <?php if ( stripslashes(bd_get_option($item['id'].'_transform')) == 'normal'  ) { echo 'selected="selected"'; } ?>>Normal</option>
				<option value="uppercase" <?php if ( stripslashes(bd_get_option($item['id'].'_transform')) == 'uppercase'  ) { echo 'selected="selected"'; } ?>>Uppercase</option>
			</select>
		</div>

		<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?>
				<br><small><?php echo $desc; ?></small>
			</label>
			
		<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>" class="bd_font_select">
			<?php foreach ($item['options'] as $v => $o) { ?>
			<option value="<?php echo $v; ?>" <?php if ( stripslashes(bd_get_option($item['id'])) == $v  ) { echo 'selected="selected"'; } ?>><?php echo $o; ?></option>
			<?php } ?>
		</select>

			<div class="bd_font_preview" style="display:inline-block; margin:25px 0 0 10%; font-size:250%; font-family:<?php echo ( bd_get_option($item['id']) ) ? stripslashes( bd_get_option($item['id']) ) : $def; ?>; ">
				L<span style="text-transform: <?php echo ( bd_get_option($item['id'].'_transform') ) ? stripslashes( bd_get_option($item['id'].'_transform') ) : 'normal';  ?>">orem ipsum</span>
			</div>
			
			<div class="clear"></div>
		</div>


	<?php elseif( $type == 'font-body' ):

		$size = '';

		if( bd_get_option($item['id']) == 'Times New Roman' || bd_get_option($item['id']) == 'Geneva' ){
			
			$size  = 'font-size:14px';  

		} 

		?>
		<div class="bd_input bd_select">
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?>
				<br><small><?php echo $desc; ?></small>
			</label>
			
		<select name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>"  class="bd_font_select">
			<?php foreach ($item['options'] as $v => $o) { ?>
			<option value="<?php echo $v; ?>" <?php if ( stripslashes(bd_get_option('body_font')) == $v  ) { echo 'selected="selected"'; } ?>><?php echo $o; ?></option>
			<?php } ?>
		</select>

			<span class="bd_font_preview" style="display:inline-block;margin:15px 0 0 10%; font-family:<?php echo ( bd_get_option($item['id']) ) ? stripslashes( bd_get_option($item['id']) ) : $def; ?>; <?php echo $size; ?>">I am a Preview</span>
			<div class="clear"></div>
		</div>

	<?php elseif( $type == 'colorpicker' ): ?>

		<style type="text/css">
			#colorSelector<?php echo $item['id']; ?> {
					position: relative;
					margin-top:8px;
					width: 36px;
					height: 36px;
					float:left;
					background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png);
				}

			#colorSelector<?php echo $item['id']; ?> div {
				position: absolute;
				top: 3px;
				left: 3px;
				width: 30px;
				height: 30px;
				background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png) center;
				border-radius:5px; -moz-border-radius:5px; -o-border-radius:5px; -webkit-border-radius:5px;
				-ms-border-radius: 5px;-khtml-border-radius: 5px;
				cursor:pointer;
			}
		</style>
		<script type="text/javascript">
			jQuery(document).ready(function($){
			$('#colorSelector<?php echo $item['id']; ?>').ColorPicker({
					color: '<?php echo ( bd_get_option($item['id']) ) ? htmlentities( stripslashes(bd_get_option($item['id']) ) ) : $def; ?>',
					onShow: function (colpkr) {
						$(colpkr).fadeIn(500);
						return false;
					},
					onHide: function (colpkr) {
						$(colpkr).fadeOut(500);
						return false;
					},
					onChange: function (hsb, hex, rgb) {
						$('#colorSelector<?php echo $item['id']; ?> div').css('backgroundColor', '#' + hex);
						$("#<?php echo $item['id']; ?>").val('#'+hex);
					}
				});
		});
		</script>
		<div class="bd_input bd_text">
			
			<label for="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]"><?php echo $item['name']; ?><br>
				<small><?php echo $desc; ?></small>
			</label>
			<div id="colorSelector<?php echo $item['id']; ?>">
				<div style="background-color:<?php echo ( bd_get_option($item['id']) ) ? htmlentities(stripslashes( bd_get_option($item['id']) ) ) : $def; ?>">
				</div>
			</div>
		 	<input name="<?php echo $prefix; ?>[<?php echo $item['id']; ?>]" id="<?php echo $item['id']; ?>" style="width:75px" type="text" value="<?php echo ( bd_get_option($item['id']) ) ? htmlentities( stripslashes( bd_get_option($item['id']) ) ) : $def; ?>">
		 	<a href="#" class="reset">reset</a>
		 	<div class="clear"></div>
		 
		</div>

    	<?php
    	endif;

} // end bd_do_input function

} //end Class
?>
