<?php
/**
*  Check template file name
* @return boolean
*/
if(!function_exists('bd_is_page')):
function bd_is_page($name){
	if(is_page_template('template-'.$name.'.php'))
		return true;
}
endif;

/**
 * Get "blog" URL
 *
 * @return string The URL of the "blog" page
 */
if ( !function_exists( 'bd_blog_url' ) ) {
    function bd_blog_url(){
        if( $posts_page_id = get_option('page_for_posts') ){
            return home_url(get_page_uri($posts_page_id));
        } else {
            return home_url();
        }
    }
}


/**
* Get comment number
* @return string : XX comments
*/
function bd_comment_number($link = true)
{
	$num_comments = get_comments_number(); //  numeric item  comments
	if ( comments_open() ){
		if($num_comments == 0){
			$comments = __('No Response', 'bd');
	}
	elseif($num_comments > 1){
		$comments = $num_comments.' '.__('Responses', 'bd');
	}
	else{
		$comments ='1 '. __('Responses', 'bd');
	}
	if($link==false)
		$write_comments = $comments;
	else
		$write_comments = '<a title="'.__('Leave a reply', 'bd').'" href="'.get_comments_link().'">'. $comments.'</a>';

	}
	else{ $write_comments = ''; 
	//$write_comments =  ''.__('Responses are off', 'bd'); 
	}
	echo $write_comments;
}


/**
* If no featured image is set, return the URL of the first image attached
* @param string : image format
* @return string :  URL
*/
function bd_get_post_thumbnail_url($format = 'medium', $post_id = null )
{
	global $post;

	if( is_object($post) && isset($post->ID) && $post_id == null )
		$ID = $post->ID;
	else
		$ID = $post_id;

	if ( $ID && has_post_thumbnail($ID) ) {

		$attachment_id =  get_post_thumbnail_id($ID);
		if($attachment_id){
			$img_src = wp_get_attachment_image_src( $attachment_id, $format); 
			return $img_src[0];
		}
	}
}

/**
* Return the URL of an embed video code
* youtube, vimeo, dailymotion
*/
function bd_get_video_url($string){
	
	$url = null;
	
	$reg_exUrl = '`\b(([\w-]+://?|www[.])[^\s()<>]+(?:\([\w\d]+\)|([^[:punct:]\s]|/)))`';
	
	if( preg_match($reg_exUrl, $string, $match) )
		$url = $match[0];
	
	$video_url = $url;
	
	/* Is Vimeo
	-----------------------------------------------------*/
	$is_vimeo = preg_match('#vimeo#', $url);
	if($is_vimeo){
		$video_url = str_replace( array('video/', 'player.'), '', $url);
	}

	/* Is Dailymotion
	-----------------------------------------------------*/
	$is_dailymotion = preg_match('#dailymotion#', $url);
	if($is_dailymotion){
		$video_url = str_replace( array('/embed'), '', $url);
	}


	return esc_url( $video_url );
}


/**
* Get theme option
* @param string : option id
* @return string : option value
*/
function bd_get_option($item = null){
	global $options;

	$bd_framework_options = get_option('bd_theme_options');

	if( isset($bd_framework_options[$item]) )
		return $bd_framework_options[$item];
	else
		return null;
}


/**
* Create a formated sample of any text
* @param string : text
* @param int : number of characters
* @return string : output text sample
*/
if(!function_exists('bd_sample')):
function bd_sample($text, $nbcar = 200){   
	$text= strip_tags($text);   
	
	if(strlen($text)>$nbcar) {
		
		preg_match('!.{0,'.$nbcar.'}\s!si', $text, $match);
		if(isset($match[0]))
			$str= trim($match[0]).'...';
		else
			$str=$text; 

	}else {
		$str=$text;  
	}
		$str = preg_replace('/\s\s+/', '', $str);
	return $str;
}
endif;


/**
* Display WP pagination
*/
if(!function_exists('bd_pagination')):
function bd_pagination($loop = null)
{

	if(!$loop){
		global $wp_query;
		$max = $wp_query->max_num_pages;
	}else{
		$max = $loop->max_num_pages;
	}
		$big = 999999999; // need an unlikely integer
		$args = array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'prev_text'    => '&lsaquo;',
			'next_text'    => '&rsaquo;',
			'current' => max( 1, get_query_var('paged') ),
			'total' => $max
		);

	echo paginate_links( $args).'<div class="clear" style="clear:both"></div>';
}
endif;

/**
* Convert a string to URL format
* In short  : clean a string for URL
* @param string
* @return string
*/
if ( ! function_exists( 'bd_to_slug' ) ) :
function bd_to_slug($string){
    $string=strtolower($string);
    $search = array('@[éèêëÊË]@i','@[àâäÂÄ]@i','@[îïÎÏ]@i','@[ûùüÛÜ]@i','@[ôöÔÖ]@i','@[ç]@i','@[^a-zA-Z0-9]@');
    $replace = array('e','a','i','u','o','c','-');
    return preg_replace($search, $replace, $string);
}
endif;
?>