<?php
/*--------------------------------------------------------------------------------------------------------------

	Plugin Name: Bd jPlayer Plugin
	Plugin URI: http://themes.brutaldesign.com
	Description: Manage your jPlayer playlist
	Version: 1.0.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

----------------------------------------------------------------------------------------------------------------*/

class BdJplayer{

	function __construct(){

		define('BD_JPLAYER_PLUGIN_URL', BD_FEATURES_URL.basename(dirname(__FILE__)).'/');
		define('BD_JPLAYER_PLUGIN_DIR', dirname(__FILE__) );
		
		/* Files upload dir and URL*/
		define('BD_JPLAYER_FILES_DIR', BD_THEME_UPLOAD_DIR . '/bd-jplayer');
		define('BD_JPLAYER_FILES_URL',  BD_THEME_UPLOAD_URL . 'bd-jplayer/');

		if(function_exists('bd_create_folder')){

			bd_create_folder(BD_JPLAYER_FILES_DIR);
			bd_create_folder(BD_JPLAYER_FILES_DIR . '/mp3');
			bd_create_folder(BD_JPLAYER_FILES_DIR . '/ogg');
			bd_create_folder(BD_JPLAYER_FILES_DIR . '/posters');
			bd_create_folder(BD_JPLAYER_FILES_DIR . '/logos');

		}else{
			bd_admin_notices(__('Could not find bd_create_folder function', 'bd'), 'error');
		}

		
		add_action('init', array(&$this, 'options_init') );
		add_action('after_setup_theme',  array(&$this, 'jplayer_show') );

		add_action('admin_init', array(&$this, 'create_jplayer_table') );
		add_action('admin_init', array(&$this, 'admin_init'));
		add_action('admin_menu', array(&$this, 'add_menu'));

		add_action('admin_print_styles', array(&$this, 'admin_styles'));
		add_action('admin_enqueue_scripts', array(&$this, 'admin_script'));

	}

	function create_jplayer_table()
	{
		global $wpdb;

		$jplayer_playlists_table = "CREATE  TABLE IF NOT EXISTS `{$wpdb->prefix}bd_jplayer_playlists` (
			`id` INT NOT NULL AUTO_INCREMENT ,
			`name` VARCHAR(255) NOT NULL ,
			`logo` VARCHAR(255) NULL ,
			`autoplay` VARCHAR(20) NULL ,
			PRIMARY KEY (`id`) );";

		$jplayer_table = "CREATE  TABLE IF NOT EXISTS `{$wpdb->prefix}bd_jplayer` (
			`id` INT NOT NULL AUTO_INCREMENT ,
			`mp3` VARCHAR(255) NULL ,
			`ogg` VARCHAR(255) NULL ,
			`name` VARCHAR(255) NULL ,
			`artist` VARCHAR(255) NULL ,
			`poster` VARCHAR(255) NULL ,
			`free` VARCHAR(45) NULL ,
			`itunes` VARCHAR(255) NULL ,
			`amazon` VARCHAR(255) NULL ,
			`buy` VARCHAR(255) NULL ,
			`position` INT NULL DEFAULT 0 ,
			`playlist_id` INT NULL ,
			PRIMARY KEY (`id`) );";

		$wpdb->query($jplayer_playlists_table);
		$wpdb->query($jplayer_table);
	}

	// --------------------------------------------------------------------------


	function admin_styles()
	{
		if(is_admin())
			wp_register_style('bd-jplayer-admin', BD_JPLAYER_PLUGIN_URL.'css/bd-jplayer-admin.css', array(), '0.1', 'all');
			wp_enqueue_style( 'bd-jplayer-admin' );
	}

	// --------------------------------------------------------------------------

	function admin_script()
	{
		if(is_admin())
			wp_enqueue_script( 'jquery-ui-sortable' );
	}


	// --------------------------------------------------------------------------


	function add_menu()
	{
		add_menu_page('jPlayer', __('jPlayer', 'bd'), 'administrator',basename(__FILE__), array( &$this, 'jplayer_panel' ) , '');
		add_submenu_page(basename(__FILE__),'','','administrator',basename(__FILE__), array( &$this,'jplayer_panel' ) );
		add_submenu_page(basename(__FILE__),  __('Manage playlists', 'bd'), __('Manage playlists', 'bd'), 'administrator', 'bd-jplayer-panel', array( &$this, 'jplayer_panel' ) );
		//add_submenu_page(basename(__FILE__),  __('Options', 'bd'), __('Options', 'bd'), 'administrator', 'bd-jplayer-settings', array(&$this, 'jplayer_settings'));
		//add_submenu_page(basename(__FILE__), __('Manual Upload', 'bd'), __('Manual Upload', 'bd'), 'administrator', 'bd-jplayer-manual', array( &$this, 'jplayer_manual' ) );
	}

	// --------------------------------------------------------------------------

	function admin_init()
	{
		register_setting( 'bd-jplayer-settings', 'bd_jplayer_settings', array(&$this, 'settings_validate') );
		add_settings_section( 'bd-jplayer-settings', '', array(&$this, 'section_intro'), 'bd-jplayer-settings' );
		add_settings_field( 'autoplay', __( 'autoplay', 'bd' ), array(&$this, 'setting_autoplay'), 'bd-jplayer-settings', 'bd-jplayer-settings' );
	}

	// --------------------------------------------------------------------------

	function options_init()
	{
		global $options;

		if ( false === get_option('bd_jplayer_settings') ) {

			$default = array(
				'autoplay' => 'true',
			);

			add_option( 'bd_jplayer_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	function settings_validate($input)
	{
		return $input;
	}

	// --------------------------------------------------------------------------

	function section_intro()
	{
		//debug($this->get_jplayer_option());
	}

	// --------------------------------------------------------------------------

	function setting_autoplay()
	{
		echo '';
	}

	// --------------------------------------------------------------------------


	function jplayer_settings()
	{
		?>
		<div class="wrap">
			<div id="icon-themes" class="icon32"></div>
			<h2><?php _e('jPlayer Settings', 'bd'); ?></h2>
			<form action="options.php" method="post">
				<?php settings_fields( 'bd-jplayer-settings' ); ?>
				<?php do_settings_sections( 'bd-jplayer-settings' ); ?>
				<p class="submit"><input name="save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'bd' ); ?>" /></p>
			</form>
			<p style="margin-top:20px"><?php _e('Visit the official jPlayer Website', 'bd'); ?>:<br>
				<a target="_blank" href="http://jplayer.org">http://jplayer.org</a></p>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------

	function get_jplayer_option($value = null)
	{
		global $options;

		$bd_jplayer_settings = get_option('bd_jplayer_settings');
		
		if( isset($bd_jplayer_settings[$value]) )
			return $bd_jplayer_settings[$value];
		else
			return null;
	}

	// --------------------------------------------------------------------------

	function jplayer_panel()
	{
		require_once BD_JPLAYER_PLUGIN_DIR . '/bd-jplayer-panel.php';
	}

	// --------------------------------------------------------------------------

	function jplayer_manual()
	{
		require_once BD_JPLAYER_PLUGIN_DIR . '/bd-jplayer-manual.php';
	}

	// --------------------------------------------------------------------------

	function jplayer_show()
	{
		require_once BD_JPLAYER_PLUGIN_DIR . '/bd-jplayer-show.php';
	}

	

} // end class
$bd_jplayer = new BdJplayer;
?>