<?php
/*--------------------------------------------------------------------------------------------------------------

	Plugin Name: Bd Nivo Slider Plugin
	Plugin URI: http://themes.brutaldesign.com
	Description: Manage your image and display a responsive slider in your theme (in-buit plugin)
	Version: 1.1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

----------------------------------------------------------------------------------------------------------------*/

class BdNivoSlider {


	function __construct(){
		define('BD_NIVOSLIDER_URL', BD_FEATURES_URL.basename(dirname(__FILE__)).'/');
		define('BD_NIVOSLIDER_DIR', dirname(__FILE__) );
		
		/* Files upload dir and URL*/
		define('BD_NIVOSLIDER_FILES_DIR', BD_THEME_UPLOAD_DIR . '/bd-nivoslider');
		define('BD_NIVOSLIDER_FILES_URL', BD_THEME_UPLOAD_URL . 'bd-nivoslider/');
	
		if(function_exists('bd_create_folder')){
			
			bd_create_folder(BD_NIVOSLIDER_FILES_DIR);
			bd_create_folder(BD_NIVOSLIDER_FILES_DIR.'/slides');

		}else{

			bd_admin_notices( __('Unable to find bd_create_folder function.', 'bd'), 'error' );
		}

		add_action('init', array(&$this, 'options_init') );
		add_action('after_setup_theme',  array(&$this, 'nivoslider_show') );

		add_action('admin_init', array(&$this, 'create_table') );
		add_action('admin_init', array(&$this, 'admin_init'));

		add_action('admin_menu', array(&$this, 'menu_init'));

		add_action('admin_print_styles', array(&$this, 'admin_styles'));
		add_action('admin_enqueue_scripts', array(&$this, 'admin_script'));

	}

	// --------------------------------------------------------------------------

	/**
	* Create nivoslider Table
	*/
	function create_table()
	{
		global $wpdb;
		$slider_tbl ="CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}bd_nivoslider` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `img` varchar(255) NOT NULL,
		  `link` text NULL,
		  `name` text NULL,
		  `caption` text NULL,
		  `position` int(11) NOT NULL DEFAULT 0,
		  `coordinates` varchar(255) NULL,
		  `language_code` varchar(7) NOT NULL DEFAULT 'en',
		  PRIMARY KEY (`id`)
		);";
		$wpdb->query($slider_tbl);

	}

	// --------------------------------------------------------------------------


	function admin_styles()
	{
		if(isset( $_GET['page'] ) ){
			
			$page = $_GET['page'];
			
			if( $page == 'bd-nivoslider-panel' || $page == 'bd-nivoslider.php' ){

				wp_enqueue_style('bd-nivoslider-admin', BD_NIVOSLIDER_URL.'css/bd-admin.css', array(), '0.1', 'all');
				wp_enqueue_style('imagareaselect', BD_NIVOSLIDER_URL.'css/imgareaselect/imgareaselect-animated.css', array(), '0.9.8', 'all');
			}
		}
	}

	// --------------------------------------------------------------------------

	function admin_script()
	{
		if( isset( $_GET['page'] ) ){
			$page = $_GET['page'];
			
			$page = $_GET['page'];
			
			if( $page == 'bd-nivoslider-panel' || $page == 'bd-nivoslider.php' ){

				wp_enqueue_script( 'imagareaselect', BD_NIVOSLIDER_URL.'js/jquery.imgareaselect.pack.js', 'jquery', '0.9.8', true );
				
				if( !wp_script_is( 'jquery-ui-sortable' ) )
					wp_enqueue_script( 'jquery-ui-sortable' );
			}
		}
	}

	// --------------------------------------------------------------------------

	function menu_init()
	{
		// Add Contextual menu
		add_menu_page('Nivo Slider', 'Nivo Slider', 'administrator', basename(__FILE__), array(&$this, 'nivoslider_panel'), '');
		add_submenu_page(basename(__FILE__),'','','administrator',basename(__FILE__),array(&$this, 'nivoslider_panel'));
		add_submenu_page(basename(__FILE__), 'Images', 'Images', 'administrator', 'bd-nivoslider-panel',  array(&$this, 'nivoslider_panel') );
		add_submenu_page(basename(__FILE__),  'Nivo Slider Options', 'Options', 'administrator', 'bd-nivoslider-settings', array(&$this, 'nivoslider_settings'));

	}


	// --------------------------------------------------------------------------

	function admin_init()
	{
		register_setting( 'bd-nivoslider-settings', 'bd_nivoslider_settings', array(&$this, 'settings_validate') );
		add_settings_section( 'bd-nivoslider-settings', '', array(&$this, 'section_intro'), 'bd-nivoslider-settings' );
		add_settings_field( 'height', __( 'Height', 'bd' ), array(&$this, 'setting_height'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'effect', __( 'Transition Effect', 'bd' ), array(&$this, 'setting_effect'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'delay', __( 'Time between animation in milliseconds', 'bd' ), array(&$this, 'setting_delay'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'transition_duration', __( 'Transition Duration', 'bd' ), array(&$this, 'setting_transition_duration'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'navigation', __( 'Navigation Bullet', 'bd' ), array(&$this, 'setting_navigation'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'arrows', __( 'Navigation Arrows', 'bd' ), array(&$this, 'setting_arrows'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'hover', __( 'Stop on hover', 'bd' ), array(&$this, 'setting_hover'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'manual', __( 'Disable Autoplay', 'bd' ), array(&$this, 'setting_manual'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'random', __( 'Start on a random slide', 'bd' ), array(&$this, 'setting_random'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'border', __( 'Border (in px)', 'bd' ), array(&$this, 'setting_border'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'border_radius', __( 'Border Radius (in px)', 'bd' ), array(&$this, 'setting_border_radius'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'border_color', __( 'Border color', 'bd' ), array(&$this, 'setting_border_color'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
		add_settings_field( 'shadow_color', __( 'Shadow color', 'bd' ), array(&$this, 'setting_shadow_color'), 'bd-nivoslider-settings', 'bd-nivoslider-settings' );
	}

	// --------------------------------------------------------------------------

	function options_init()
	{
		global $options;

		if ( false === get_option('bd_nivoslider_settings') ) {

			$default = array(
				'height' => 300,
				'manual' => 'false',
				'delay' => 4000,
				'effect' => 'random',
				'transition_duration' => 500,
				'navigation' => 'true',
				'arrows' => 'true',
				'hover' => 'true',
				'random' => 'false',
				'border' => 10,
				'border_radius' => 7,
				'border_color' => '#181818',
				'shadow_color' => '#000000'

			);

			add_option( 'bd_nivoslider_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	function section_intro()
	{
		// global $options;
		// debug(get_option('bd_nivoslider_settings'));
	}

	// --------------------------------------------------------------------------

	function settings_validate($input)
	{
		$input['height'] = intval( $input['height'] );
		$input['delay'] = intval( $input['delay'] );
		$input['border'] = intval( $input['border'] );
		$input['border_radius'] = intval( $input['border_radius'] );
		$input['transition_duration'] = intval( $input['transition_duration'] );
		$input['effect'] = esc_attr( $input['effect'] );
		$input['border_color'] = esc_attr( $input['border_color'] );

		return $input;
	}

	// --------------------------------------------------------------------------

	function setting_height()
	{
		
		echo '<input type="text" name="bd_nivoslider_settings[height]" class="regular-text" value="'. $this->get_nivoslider_option('height') .'">';
	}

	// --------------------------------------------------------------------------

	function setting_delay()
	{
		
		echo '<input type="text" name="bd_nivoslider_settings[delay]" class="regular-text" value="'. $this->get_nivoslider_option('delay') .'">';
	}

	// --------------------------------------------------------------------------

	function setting_transition_duration()
	{
		
		echo '<input type="text" name="bd_nivoslider_settings[transition_duration]" class="regular-text" value="'. $this->get_nivoslider_option('transition_duration') .'">';
	}

	// --------------------------------------------------------------------------


	function setting_manual()
	{
		echo '<input type="hidden" name="bd_nivoslider_settings[manual]" value="false" />
		<label><input type="checkbox" name="bd_nivoslider_settings[manual]" value="true"'. (($this->get_nivoslider_option('manual') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------


	function setting_hover()
	{
		echo '<input type="hidden" name="bd_nivoslider_settings[hover]" value="false" />
		<label><input type="checkbox" name="bd_nivoslider_settings[hover]" value="true"'. (($this->get_nivoslider_option('hover') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------


	function setting_random()
	{
		echo '<input type="hidden" name="bd_nivoslider_settings[random]" value="false" />
		<label><input type="checkbox" name="bd_nivoslider_settings[random]" value="true"'. (($this->get_nivoslider_option('random') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------

	function setting_effect()
	{	$effects = array('random',
		'sliceDown',
		'sliceDownLeft',
		'sliceUp',
		'sliceUpLeft',
		'sliceUpDown',
		'sliceUpDownLeft',
		'fold',
		'fade',
		'slideInRight',
		'slideInLeft',
		'boxRandom',
		'boxRain',
		'boxRainReverse',
		'boxRainGrow',
		'boxRainGrowReverse',
		);
		?>
		<select name="bd_nivoslider_settings[effect]">
			<?php foreach($effects as $e): ?>
			<option value="<?php echo $e; ?>" <?php if($this->get_nivoslider_option('effect') == $e) echo 'selected="selected"' ?>><?php echo $e; ?></option>
			<?php endforeach; ?>
		</select>
		<?php
	}

	// --------------------------------------------------------------------------

	function setting_navigation()
	{	
		echo '<input type="hidden" name="bd_nivoslider_settings[navigation]" value="false" />
		<label><input type="checkbox" name="bd_nivoslider_settings[navigation]" value="true"'. (($this->get_nivoslider_option('navigation') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------

	function setting_arrows()
	{	
		echo '<input type="hidden" name="bd_nivoslider_settings[arrows]" value="false" />
		<label><input type="checkbox" name="bd_nivoslider_settings[arrows]" value="true"'. (($this->get_nivoslider_option('arrows') == 'true') ? ' checked="checked"' : '') .' /></label><br>';
	}

	// --------------------------------------------------------------------------


	function setting_border()
	{
		
		echo '<input type="text" name="bd_nivoslider_settings[border]" class="regular-text" value="'. $this->get_nivoslider_option('border') .'">';
	}

	// --------------------------------------------------------------------------


	function setting_border_radius()
	{
		
		echo '<input type="text" name="bd_nivoslider_settings[border_radius]" class="regular-text" value="'. $this->get_nivoslider_option('border_radius') .'">';
	}

	// --------------------------------------------------------------------------


	function setting_border_color()
	{
		?>
		<style type="text/css">
			#colorSelector-border_color {
					position: relative;
					margin-top:8px;
					width: 36px;
					height: 36px;
					float:left;
					background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png);
				}

			#colorSelector-border_color div {
				position: absolute;
				top: 3px;
				left: 3px;
				width: 30px;
				height: 30px;
				background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png) center;
				border-radius:5px; -moz-border-radius:5px; -o-border-radius:5px; -webkit-border-radius:5px;
				-ms-border-radius: 5px;-khtml-border-radius: 5px;
				cursor:pointer;
			}
		</style>
		<script type="text/javascript">
			jQuery(document).ready(function($){
			$('#colorSelector-border_color').ColorPicker({
					color: '<?php echo $this->get_nivoslider_option('border_color'); ?>',
					onShow: function (colpkr) {
						$(colpkr).fadeIn(500);
						return false;
					},
					onHide: function (colpkr) {
						$(colpkr).fadeOut(500);
						return false;
					},
					onChange: function (hsb, hex, rgb) {
						$('#colorSelector-border_color div').css('backgroundColor', '#' + hex);
						$("#bd-nivoslider-border_color").val('#'+hex);
					}
				});
		});
		</script>
			
		<div id="colorSelector-border_color" style="margin-top: -2px;">
			<div style="background-color:<?php echo $this->get_nivoslider_option('border_color'); ?>">
			</div>
		</div>
	 	<input name="bd_nivoslider_settings[border_color]" id="bd-nivoslider-border_color" style="width:75px" type="text" value="<?php echo $this->get_nivoslider_option('border_color'); ?>">
	 	<a href="#" class="reset">reset</a>
	 	<div class="clear"></div>
		 
		<?php
	}

	// --------------------------------------------------------------------------


	function setting_shadow_color()
	{
		?>
		<style type="text/css">
			#colorSelector-shadow_color {
					position: relative;
					margin-top:8px;
					width: 36px;
					height: 36px;
					float:left;
					background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png);
				}

			#colorSelector-shadow_color div {
				position: absolute;
				top: 3px;
				left: 3px;
				width: 30px;
				height: 30px;
				background: url(<?php echo BD_FRAMEWORK_URL; ?>css/colorpicker/images/select.png) center;
				border-radius:5px; -moz-border-radius:5px; -o-border-radius:5px; -webkit-border-radius:5px;
				-ms-border-radius: 5px;-khtml-border-radius: 5px;
				cursor:pointer;
			}
		</style>
		<script type="text/javascript">
			jQuery(document).ready(function($){
			$('#colorSelector-shadow_color').ColorPicker({
					color: '<?php echo $this->get_nivoslider_option('shadow_color'); ?>',
					onShow: function (colpkr) {
						$(colpkr).fadeIn(500);
						return false;
					},
					onHide: function (colpkr) {
						$(colpkr).fadeOut(500);
						return false;
					},
					onChange: function (hsb, hex, rgb) {
						$('#colorSelector-shadow_color div').css('backgroundColor', '#' + hex);
						$("#bd-nivoslider-shadow_color").val('#'+hex);
					}
				});
		});
		</script>
			
		<div id="colorSelector-shadow_color" style="margin-top: -2px;">
			<div style="background-color:<?php echo $this->get_nivoslider_option('shadow_color'); ?>">
			</div>
		</div>
	 	<input name="bd_nivoslider_settings[shadow_color]" id="bd-nivoslider-shadow_color" style="width:75px" type="text" value="<?php echo $this->get_nivoslider_option('shadow_color'); ?>">
	 	<a href="#" class="reset">reset</a>
	 	<div class="clear"></div>
		 
		<?php
	}

	// --------------------------------------------------------------------------


	function nivoslider_settings()
	{
		?>
		<div class="wrap">
			<div id="icon-themes" class="icon32"></div>
			<h2><?php _e('nivoslider Settings', 'bd'); ?></h2>
			<form action="options.php" method="post">
				<?php settings_fields( 'bd-nivoslider-settings' ); ?>
				<?php do_settings_sections( 'bd-nivoslider-settings' ); ?>
				<p class="submit"><input name="save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'bd' ); ?>" /></p>
			</form>
			<p style="margin-top:20px"><?php _e('Visit the official nivoslider Website', 'bd'); ?>:<br>
				<a target="_blank" href="http://nivoslider.frebsite.nl/">http://nivoslider.frebsite.nl/</a></p>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------

	function get_nivoslider_option($value = null)
	{
		global $options;

		$bd_nivoslider_settings = get_option('bd_nivoslider_settings');
		
		if( isset($bd_nivoslider_settings[$value]) )
			return $bd_nivoslider_settings[$value];
		else
			return null;
	}

	// --------------------------------------------------------------------------

	function nivoslider_panel()
	{
		include_once BD_NIVOSLIDER_DIR . '/bd-nivoslider-panel.php';
	}

	// --------------------------------------------------------------------------

	function nivoslider_show()
	{
		include_once BD_NIVOSLIDER_DIR . '/bd-nivoslider-show.php';
	}


} // end class
$bd_nivoslider = new BdNivoSlider;
?>