<?php
/*--------------------------------------------------------------------------------------------------------------

	Plugin Name: Bd Piecemaker Plugin
	Plugin URI: http://themes.brutaldesign.com
	Description: Manage your image and display a responsive slider in your theme (in-buit plugin)
	Version: 1.2.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

----------------------------------------------------------------------------------------------------------------*/

class BdPiecemaker {


	function __construct(){
		define('BD_PIECEMAKER_URL', BD_FEATURES_URL.basename(dirname(__FILE__)).'/');
		define('BD_PIECEMAKER_DIR', dirname(__FILE__) );
		
		/* Files upload dir and URL*/
		define('BD_PIECEMAKER_FILES_DIR', BD_THEME_UPLOAD_DIR . '/bd-piecemaker');
		define('BD_PIECEMAKER_FILES_URL',  BD_THEME_UPLOAD_URL . 'bd-piecemaker/');
	
		if(function_exists('bd_create_folder')){
			
			bd_create_folder(BD_PIECEMAKER_FILES_DIR);
			bd_create_folder(BD_PIECEMAKER_FILES_DIR.'/slides');

		}else{

			bd_admin_notices( __('Unable to find bd_create_folder function.', 'bd'), 'error' );
		}

		add_action('init', array(&$this, 'options_init') );
		add_action('after_setup_theme',  array(&$this, 'piecemaker_show') );

		add_action('admin_init', array(&$this, 'create_table') );
		add_action('admin_init', array(&$this, 'admin_init'));

		add_action('admin_menu', array(&$this, 'menu_init'));

		add_action('admin_print_styles', array(&$this, 'admin_styles'));
		add_action('admin_enqueue_scripts', array(&$this, 'admin_script'));

	}

	// --------------------------------------------------------------------------

	/**
	* Create piecemaker Table
	*/
	function create_table()
	{
		global $wpdb;
		$slider_tbl ="CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}bd_piecemaker` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `img` varchar(255) NOT NULL,
		  `name` text NULL,
		  `position` int(11) NOT NULL DEFAULT 0,
		  `coordinates` varchar(255) NULL,
		  `language_code` varchar(7) NOT NULL DEFAULT 'en',
		  PRIMARY KEY (`id`)
		);";
		$wpdb->query($slider_tbl);

	}

	// --------------------------------------------------------------------------


	function admin_styles()
	{
		if(isset( $_GET['page'] ) ){
			
			$page = $_GET['page'];
			
			if( $page == 'bd-piecemaker-panel' || $page == 'bd-piecemaker.php' ){

				wp_enqueue_style('bd-piecemaker-admin', BD_PIECEMAKER_URL.'css/bd-admin.css', array(), '0.1', 'all');
				wp_enqueue_style('imagareaselect', BD_PIECEMAKER_URL.'css/imgareaselect/imgareaselect-animated.css', array(), '0.9.8', 'all');
			}
		}
	}

	// --------------------------------------------------------------------------

	function admin_script()
	{
		if( isset( $_GET['page'] ) ){
			$page = $_GET['page'];
			
			$page = $_GET['page'];
			
			if( $page == 'bd-piecemaker-panel' || $page == 'bd-piecemaker.php' ){

				wp_enqueue_script( 'imagareaselect', BD_PIECEMAKER_URL.'js/jquery.imgareaselect.pack.js', 'jquery', '0.9.8', true );
				
				if( !wp_script_is( 'jquery-ui-sortable' ) )
					wp_enqueue_script( 'jquery-ui-sortable' );
			}
		}
	}

	// --------------------------------------------------------------------------

	function menu_init()
	{
		// Add Contextual menu
		add_menu_page('Piecemaker Slider', 'Piecemaker Slider', 'administrator', basename(__FILE__), array(&$this, 'piecemaker_panel'), '');
		add_submenu_page(basename(__FILE__),'','','administrator',basename(__FILE__),array(&$this, 'piecemaker_panel'));
		add_submenu_page(basename(__FILE__), 'Images', 'Images', 'administrator', 'bd-piecemaker-panel',  array(&$this, 'piecemaker_panel') );
		add_submenu_page(basename(__FILE__),  'Piecemaker Slider Options', 'Options', 'administrator', 'bd-piecemaker-settings', array(&$this, 'piecemaker_settings'));

	}


	// --------------------------------------------------------------------------

	function admin_init()
	{
		register_setting( 'bd-piecemaker-settings', 'bd_piecemaker_settings', array(&$this, 'settings_validate') );
		add_settings_section( 'bd-piecemaker-settings', '', array(&$this, 'section_intro'), 'bd-piecemaker-settings' );
		add_settings_field( 'height', __( 'Height', 'bd' ), array(&$this, 'setting_height'), 'bd-piecemaker-settings', 'bd-piecemaker-settings' );
		add_settings_field( 'delay', __( 'Time between animation in seconds', 'bd' ), array(&$this, 'setting_delay'), 'bd-piecemaker-settings', 'bd-piecemaker-settings' );
	}

	// --------------------------------------------------------------------------

	function options_init()
	{
		global $options;

		if ( false === get_option('bd_piecemaker_settings') ) {

			$default = array(
				'height' => 300,
				'delay' => 4,
			);

			add_option( 'bd_piecemaker_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	function section_intro()
	{
		// global $options;
		// debug(get_option('bd_piecemaker_settings'));
	}

	// --------------------------------------------------------------------------

	function settings_validate($input)
	{
		$input['height'] = intval( $input['height'] );
		$input['delay'] = intval( $input['delay'] );
		return $input;
	}

	// --------------------------------------------------------------------------

	function setting_height()
	{
		
		echo '<input type="text" name="bd_piecemaker_settings[height]" class="regular-text" value="'. $this->get_piecemaker_option('height') .'">';
	}

	// --------------------------------------------------------------------------

	function setting_delay()
	{
		
		echo '<input type="text" name="bd_piecemaker_settings[delay]" class="regular-text" value="'. $this->get_piecemaker_option('delay') .'">';
	}

	// --------------------------------------------------------------------------


	function piecemaker_settings()
	{
		?>
		<div class="wrap">
			<div id="icon-themes" class="icon32"></div>
			<h2><?php _e('piecemaker Settings', 'bd'); ?></h2>
			<form action="options.php" method="post">
				<?php settings_fields( 'bd-piecemaker-settings' ); ?>
				<?php do_settings_sections( 'bd-piecemaker-settings' ); ?>
				<p class="submit"><input name="save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'bd' ); ?>" /></p>
			</form>
			<p style="margin-top:20px"><?php _e('Visit the official piecemaker Website', 'bd'); ?>:<br>
				<a target="_blank" href="http://piecemaker.frebsite.nl/">http://piecemaker.frebsite.nl/</a></p>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------

	function get_piecemaker_option($value = null)
	{
		global $options;

		$bd_piecemaker_settings = get_option('bd_piecemaker_settings');
		
		if( isset($bd_piecemaker_settings[$value]) )
			return $bd_piecemaker_settings[$value];
		else
			return null;
	}

	// --------------------------------------------------------------------------

	function piecemaker_panel()
	{
		include_once BD_PIECEMAKER_DIR . '/bd-piecemaker-panel.php';
	}

	// --------------------------------------------------------------------------

	function piecemaker_show()
	{
		include_once BD_PIECEMAKER_DIR . '/bd-piecemaker-show.php';
	}


} // end class
$bd_piecemaker = new BdPiecemaker;
?>