<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Bd Share
	Plugin URI: http://themes.brutaldesign.com/plugin/bd-share
	Description: Easily share your posts on Twitter, Pinterest, Facebook and Google+.
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

class BdShare{

	function __construct()
	{


		define('BD_SHARE_PLUGIN_URL', BD_FEATURES_URL.basename(dirname(__FILE__)).'/');
		define('BD_SHARE_PLUGIN_DIR', dirname(__FILE__));

		add_action('bd_meta_head', array(&$this, 'meta'));
			
		add_action('after_setup_theme', array(&$this, 'options_init') );
		add_action('wp_print_styles', array(&$this, 'print_styles'));
		add_action('wp_footer', array(&$this, 'output_script'));
		add_shortcode('bd_share', array(&$this, 'shortcode'));

		add_action('admin_init', array(&$this, 'admin_init'));
		add_action('admin_init', array(&$this, 'save'));
		add_action('admin_menu',  array(&$this, 'share_plugin_init'));
		add_action('admin_print_styles', array(&$this, 'print_styles'));
		add_action('admin_head', array(&$this, 'admin_js'));
		
		
	}

	// --------------------------------------------------------------------------
	
	/**
	* Share buttons css styles
	*/
	function print_styles()
	{
		wp_register_style('bd-share', BD_SHARE_PLUGIN_URL.'css/bd-share.css', array(), '0.1', 'all');
		wp_enqueue_style('bd-share');
	}

	// --------------------------------------------------------------------------
	
	/**
	* Set default settings
	*/
	function options_init()
	{
		global $options;

		if ( false ===  get_option('bd_share_settings')  ) {

			$default = array(
				//'text' => 'Share this post',
				'show_twitter' => 1,
				'show_facebook' => 1,
				'show_google' => 1,
				'show_pinterest' => 1,
				'layout' => 'horizontal',
				'facebook_meta' => 1,
				'google_meta' => 1,
			);

			add_option( 'bd_share_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	function admin_js()
	{

		if(isset($_GET['page']) && $_GET['page'] == basename(__FILE__)){

			echo  "<script type='text/javascript'>
		      	 jQuery(document).ready(function($){
				$('#share-image-reset').click(function(){
			 		$('#share-image-set').val('');
			 		$('#share-image-preview').hide();
					return false;  });
				$('#bd-share-submit').click(function(){
			 		$('#loader').show();
				 });
			
		      	});</script>";
		}
	}

	// --------------------------------------------------------------------------

	/**
	* Is the plugin used as usual or included in a BrutalDesign theme ?
	*/
	function is_bd_framework()
	{
		if(defined('BD_FRAMEWORK_VERSION'))
			return true;
		else
			return false;
	}

	// --------------------------------------------------------------------------


	/**
	* Add menu
	*/
	function share_plugin_init()
	{
		// Add Contextual menu
		add_menu_page(__('Share', 'bd'), __('Share', 'bd'), 'administrator', basename(__FILE__), array(&$this, 'share_settings'), '');

	}

	// --------------------------------------------------------------------------


	/**
	* Add Settings
	*/
	function admin_init()
	{
		register_setting( 'bd-share', 'bd_share_settings', array(&$this, 'settings_validate') );
		add_settings_section( 'bd-share', '', array(&$this, 'section_intro'), 'bd-share' );
		//add_settings_field( 'text', __( 'Text on single post', 'bd' ), array(&$this, 'setting_text'), 'bd-share', 'bd-share' );
		add_settings_field( 'buttons', __( 'Show', 'bd' ), array(&$this, 'setting_buttons'), 'bd-share', 'bd-share' );
		//add_settings_field( 'layout', __( 'Layout', 'bd' ), array(&$this, 'setting_layout'), 'bd-share', 'bd-share' );
		add_settings_field( 'facebook_meta', __( 'Generate Facebook Meta', 'bd' ), array(&$this, 'setting_facebook_meta'), 'bd-share', 'bd-share' );
		add_settings_field( 'google_meta', __( 'Generate Google+ Meta', 'bd' ), array(&$this, 'setting_google_meta'), 'bd-share', 'bd-share' );
		add_settings_field( 'image', __( 'Default facebook and google share image', 'bd' ), array(&$this, 'setting_image'), 'bd-share', 'bd-share' );
		add_settings_field( 'preview', __( 'Preview', 'bd' ), array(&$this, 'setting_preview'), 'bd-share', 'bd-share' );
		add_settings_field( 'instructions', __( 'Shortcode and Template Tag', 'bd' ), array(&$this, 'setting_instructions'), 'bd-share', 'bd-share' );
		add_settings_field( 'tip', __( 'Tip', 'bd' ), array(&$this, 'setting_tip'), 'bd-share', 'bd-share' );
	}

	// --------------------------------------------------------------------------

	function section_intro()
	{
		//global $options;
		//debug(get_option('bd_share_settings'));
		//debug($_POST);
		?>
		<?php
	}

	// --------------------------------------------------------------------------

	function setting_text()
	{
		echo '<input type="text" name="bd_share_settings[text]" class="regular-text" value="'. stripslashes($this->get_share_option('text')) .'">';
	}

	// --------------------------------------------------------------------------

	function setting_buttons()
	{
		echo '<input type="hidden" name="bd_share_settings[show_twitter]" value="0">
		<label><input type="checkbox" name="bd_share_settings[show_twitter]" value="1"'. (($this->get_share_option('show_twitter') == 1) ? ' checked="checked"' : '') .'>
		Twitter</label><br />
		<input type="hidden" name="bd_share_settings[show_facebook]" value="0">
		<label><input type="checkbox" name="bd_share_settings[show_facebook]" value="1"'. (($this->get_share_option('show_facebook') == 1) ? ' checked="checked"' : '') .'>
		Facebook</label><br />
		<input type="hidden" name="bd_share_settings[show_google]" value="0">
		<label><input type="checkbox" name="bd_share_settings[show_google]" value="1"'. (($this->get_share_option('show_google') == 1) ? ' checked="checked"' : '') .'>
		Google</label><br />
		<input type="hidden" name="bd_share_settings[show_pinterest]" value="0">
		<label><input type="checkbox" name="bd_share_settings[show_pinterest]" value="1"'. (($this->get_share_option('show_pinterest') == 1) ? ' checked="checked"' : '') .'>
		Pinterest</label><br />';
	}

	// --------------------------------------------------------------------------

	function setting_layout()
	{
		?>
		<select name="bd_share_settings[layout]" id="layout">
			<option value="horizontal" <?php if( $this->get_share_option('layout') == 'horizontal' ) echo 'selected="selected"'; ?>>horizontal</option>
			<option value="vertical" <?php if( $this->get_share_option('layout') == 'vertical' ) echo 'selected="selected"'; ?>>vertical</option>
		</select>
		<?php
	}

	// --------------------------------------------------------------------------


	function setting_facebook_meta()
	{
		echo '<input type="hidden" name="bd_share_settings[facebook_meta]" value="0" />
		<label><input type="checkbox" name="bd_share_settings[facebook_meta]" value="1"'. (($this->get_share_option('facebook_meta')) ? ' checked="checked"' : '') .' />
		'.__('By default, this plugin generates facebook meta automatically. If you use a third-party facebook plugin, you can disable this option to avoid conflicts', 'bd').'.</label><br />';
	}

	// --------------------------------------------------------------------------

	function setting_google_meta()
	{
		echo '<input type="hidden" name="bd_share_settings[google_meta]" value="0" />
		<label><input type="checkbox" name="bd_share_settings[google_meta]" value="1"'. (($this->get_share_option('google_meta')) ? ' checked="checked"' : '') .' /></label><br />';
	}

	// --------------------------------------------------------------------------

	function setting_image()
	{
		?>
		
	 	<input name="share_image" id="share_image" type="file">
	 	<input type="hidden" name="share_image_set" id="share-image-set" value="<?php if ( $this->get_share_option('share_image') != "") { echo "set";   } else { echo ""; } ?>">
	 	<a href="#" id="share-image-reset">reset</a>
	 	
	 	<div style="clear:both"></div>
		<?php if ( $this->get_share_option('share_image') != null): ?>
		<div style="float:left; margin: 5px; width:80px; min-height:10px">
			<img id="share-image-preview" src="<?php echo BD_SHARE_PLUGIN_URL.'userimage/'.$this->get_share_option('share_image'); ?>?<?php echo time(); ?>" alt="" width="80">
		</div>
		<?php endif; ?>
		<br><label for="share_image"><?php _e('By default, the featured image or the first image of the shared post will be shown. If the post has no image, this image will be used', 'bd'); ?>.</label>
		<?php

	}

	// --------------------------------------------------------------------------

	function setting_preview()
	{
		echo $this->render('horizontal', true);
		$this->output_script();
	}

	// --------------------------------------------------------------------------

	function setting_instructions()
	{
		echo '<p>'.__('To use BrutalDesign Share in your pages you can use the shortcode', 'bd').':</p>
		<p><code>[bd_share layout="horizontal|vertical"]</code></p>';
		

		echo '<p>'.__('To use BrutalDesign Share manually in your theme template use the following PHP code', 'bd').':</p>
			<p><code>&lt;?php if( function_exists(\'bd_share\') ) bd_share(\'horizontal | vertical\'); ?&gt;</code></p>';
	}

	// --------------------------------------------------------------------------

	function setting_tip()
	{
		echo '<p>'.__('You can check how it looks when you share an URL on your facebook wall by using this tool', 'bd').':</p>
		<p><a href="https://developers.facebook.com/tools/debug" target="_blank">https://developers.facebook.com/tools/debug</a></p>';
		
	}

	// --------------------------------------------------------------------------

	function settings_validate($input)
	{
		//$input['text'] = sanitize_text_field( $input['text'] );
		
		return $input;
	}

	// --------------------------------------------------------------------------


	function save()
	{
		if(isset($_POST['bd-share-settings-save']) && isset($_GET['page']) && $_GET['page'] == basename(__FILE__) ) :

			if ( !empty($_POST) || wp_verify_nonce($_POST['bd-share'],basename(__FILE__)) ){
				
					$newoptions = $_POST['bd_share_settings'];

					/* Image Upload */
					$img_dir = BD_SHARE_PLUGIN_DIR.'/userimage';
					if(!file_exists($img_dir)) mkdir($img_dir,0777);

					if(!empty($_FILES['share_image']['name'])){
						
						$tmp = $_FILES['share_image']['tmp_name'];
						$ext = pathinfo($_FILES['share_image']['name'], PATHINFO_EXTENSION); 
						$img_name = time().'.'.$ext;
						$img_name = wp_unique_filename($img_dir, $img_name);
						$allowed_types = array('image/jpg', 'image/jpeg', 'image/gif', 'image/png');
						
						if(in_array($_FILES['share_image']['type'], $allowed_types)){

							move_uploaded_file($tmp, $img_dir.'/'.$img_name);
						
							$newoptions['share_image'] = $img_name ;


						}

					}elseif( $_POST['share_image_set'] == null && $this->get_share_option('share_image') != null ){
						
						if(file_exists($img_dir.'/'.$this->get_share_option('share_image')))
							unlink($img_dir.'/'.$this->get_share_option('share_image'));
					 	
					 	unset($newoptions['share_image']);

					}else{

						$newoptions['share_image'] = $this->get_share_option('share_image');

					}

				update_option('bd_share_settings', $newoptions);
						
			
			}else{
				print 'Sorry, your nonce did not verify.';
	  			exit;
	  		}

	  	endif; // end if post
		
	}

	// --------------------------------------------------------------------------


	function share_settings()
	{
		?>
		<div class="wrap">
			<div id="icon-options-general" class="icon32"></div>
			<h2><?php _e('Share Buttons Settings', 'bd'); ?></h2>
			<form action="<?php echo admin_url('admin.php?page='. basename(__FILE__)); ?>" method="post" enctype="multipart/form-data">
				<?php settings_fields( 'bd-share' ); ?>
				<?php do_settings_sections( 'bd-share' ); ?>
				<p class="submit"><input style="float:left" id="bd-share-submit" name="bd-share-settings-save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'bd' ); ?>" />
				<img id="loader" style="display:none; margin-top:3px" src="<?php echo admin_url('images/loading.gif'); ?>" alt="loader">
				<div style="float:none; clear:both"></div>
				</p>
			</form>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------


	function get_share_option($value = null)
	{
	            global $options;
	            
	            $bd_share_settings = get_option('bd_share_settings');
	            if( isset($bd_share_settings[$value]) )
	                return $bd_share_settings[$value];
	            else
	                return null;
	}

	// --------------------------------------------------------------------------


	function is_third_party_seo()
	{
		include_once( ABSPATH .'wp-admin/includes/plugin.php' );

		if( is_plugin_active('headspace2/headspace.php') ) return true;
		if( is_plugin_active('all-in-one-seo-pack/all_in_one_seo_pack.php') ) return true;
		if( is_plugin_active('wordpress-seo/wp-seo.php') ) return true;

		return false;
	}

	// --------------------------------------------------------------------------


	function bd_seo_is_on()
	{
		global $options;
		$theme_options = get_option('bd_theme_options');

		if( defined('BD_SEO') && BD_SEO && !$this->is_third_party_seo() && !isset($theme_options['disable_seo']) ){
			return true;
		}else{
			return false;
		}
	}

	// --------------------------------------------------------------------------

	function do_meta()
	{
		if(!$this->is_third_party_seo() && !$this->bd_seo_is_on()){
			return true;
		}else{
			return false;
		}
	}

	// --------------------------------------------------------------------------

	function sample($text,$nbcar = 200)
	{
		$text= strip_tags($text);   
		if(strlen($text)>$nbcar) {
			
			preg_match('!.{0,'.$nbcar.'}\s!si', $text, $match);
			$str= $match[0].'... ';

		}else {
			$str=$text;  
		}
		
		$str = preg_replace('/\s\s+/', '', $str);
		return $str;
	}

	// --------------------------------------------------------------------------


	function shortcode($atts)
	{
		extract(shortcode_atts(array(
		      'layout' => 'horizontal',
		      ), $atts)
		);
		return $this->render($layout);
	}

	// --------------------------------------------------------------------------


	/**
	* Generate share buttons scripts
	* 
	*/
	function output_script()
	{
		/* Put conditino in variables */
		$facebook = $this->get_share_option('show_facebook') == 1;
		$twitter = $this->get_share_option('show_twitter') == 1;
		$google = $this->get_share_option('show_google') == 1;
		$pinterest = $this->get_share_option('show_pinterest') == 1;
		
		$output = '';

		if( $facebook )
			$output .= '<div id="fb-root"></div>'; 

		if( $facebook || $twitter || $google || $pinterest ){
			$output .= '<script type="text/javascript">';

			$output .= '(function(doc, script) {
			        var js, 
			        fjs = doc.getElementsByTagName(script)[0],
			        add = function(url, id) {
			            if (doc.getElementById(id)) {return;}
			            js = doc.createElement(script);
			            js.src = url;
			            id && (js.id = id);
			            fjs.parentNode.insertBefore(js, fjs);
			        };';
		}


		if( $facebook )
			// facebook
			$output .= 'add("//connect.facebook.net/en_US/all.js#xfbml=1", "facebook-jssdk");' . "\n";

		if( $twitter )
			// twitter
			$output .= 'add("//platform.twitter.com/widgets.js", "twitter-wjs");' . "\n";

		if( $google )
			// google plus
			$output .= 'add("https://apis.google.com/js/plusone.js");' . "\n";

		if( $pinterest )
			// pinterest
			$output .= 'add("//assets.pinterest.com/js/pinit.js");' . "\n";

		if( $facebook || $twitter || $google || $pinterest )
			$output .= '}(document, "script"));</script>' . "\n";
		
		

		// $output .='<script>
		// (function(d, s, id) {
		//       var js, fjs = d.getElementsByTagName(s)[0];
		//       if (d.getElementById(id)) return;
		//       js = d.createElement(s); js.id = id;
		//       js.src = "//connect.facebook.net/en_US/all.js#xfbml=1";
		//       fjs.parentNode.insertBefore(js, fjs);
		//     }(document, \'script\', \'facebook-jssdk\'));</script>'. "\n";
		// }

		// if($google){
		// 	$output .= '<script type="text/javascript">
		// 	    (function() {
		// 	    var po = document.createElement(\'script\'); po.type = \'text/javascript\'; po.async = true;
		// 	    po.src = \'https://apis.google.com/js/plusone.js\';
		// 	    var s = document.getElementsByTagName(\'script\')[0]; s.parentNode.insertBefore(po, s);
		// 	    })();
		// 	    </script>';
		//   }

		// if($twitter){
		// 	$output .= '<script type="text/javascript" src="//platform.twitter.com/widgets.js"></script>';
		// }

		// if($pinterest){
		// 	//$output .= '<script type="text/javascript" src="//assets.pinterest.com/js/pinit.js"></script>';
		// }
		echo $output;
	}

	// --------------------------------------------------------------------------


	function get_wp_title()
	{
		ob_start();
		wp_title();
		$wp_title = ob_get_contents();
		ob_end_clean();
		$wp_title = preg_replace("/&#?[a-z0-9]{2,8};/i","",$wp_title);
		$wp_title = preg_replace ("/\s+/", " ", $wp_title);
		return $wp_title;

	}

	// --------------------------------------------------------------------------


	/**
	* Get an image for facebook meta.
	* This function search the post featured image or, if no featured image is set, the first image in the post content 
	* If the post don't have any image, the deafult facebook thumbnail set in the theme options will be used
	* $this->get_share_option(bd_fbimage)
	*/
	function get_fb_image()
	{
		global $post, $options;
		
		/* We define the default image first and see if the post contains an image after */
		$fbimage = BD_SHARE_PLUGIN_URL.'share_image.jpg';
		if($this->get_share_option('share_image')!='')
			$fbimage = BD_SHARE_PLUGIN_URL.'userimage/'.$this->get_share_option('share_image');
		
		if(!is_404() && !is_search()){
			if ( $post ){
				if ((function_exists('has_post_thumbnail')) && (has_post_thumbnail())) {
					$src = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'medium');
					$fbimage = $src[0];
				}else{
					
					$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i',
					$post->post_content, $matches);
					if( $matches [1] )
						$fbimage = $matches [1] [0];
				}
			}

		}
				
		return $fbimage;
	}

	// --------------------------------------------------------------------------

	/**
	* Get the post description
	* Create a sample of the excerpt if it exists, or get the site description
	**/
	function get_decription()
	{
		global $post;
		$excerpt = '';
		if (!is_404() && !is_search() && $post):
			$excerpt = $post->post_excerpt;
			if($excerpt==''){
				$excerpt = strip_tags(preg_replace( '/'.get_shortcode_regex().'/i', '', $post->post_content));
				$excerpt = preg_replace ("/\s+/", " ", $excerpt);
				$excerpt = $this->sample($excerpt);
			}
		endif;
		if($excerpt == null ) 
			$excerpt = get_bloginfo ( 'description' );
		
		return $excerpt;
	}

	// --------------------------------------------------------------------------

	/**
	* Generate facebook and googleplus metatags if SEO plugin is off
	* Otherwise, that's the SEO plugin that will do it
	**/
	function meta()
	{
		global $post;
		
		if (!is_404() && $post):
		
		if (is_single() || is_page() ) 
			$fb_type = 'article';
		else  
			$fb_type = 'website'; 
		
		$fbmeta = '';
		$gpmeta = '';
		$sitename = get_bloginfo( 'name' );
		
		/*g+*/
		$gpmeta .='<meta itemprop="name" content="'.$sitename.'">' . "\n";

		$gpmeta .= '<meta itemprop="image" content="'.$this->get_fb_image().'">' . "\n";
		
		/*fb*/
		
		$fbmeta .='<meta property="og:site_name" content="'.$sitename.'" />' . "\n";
		
		$fbmeta .='<meta property="og:url" content="'.get_permalink().'" />' . "\n";
		
		$fbmeta .='<meta property="og:image" content="'.$this->get_fb_image().'" />' . "\n";
		
		if(isset($fb_type)){ 
			$fbmeta .='<meta property="og:type" content="'.$fb_type.'" />' . "\n";
		} 

		if( $this->bd_seo_is_on() && get_post_meta( $post->ID, 'bd_seo_description', true ) == null ){
			$gpmeta .='<meta itemprop="description" content="'.$this->get_decription().'">' . "\n";
			$fbmeta .='<meta property="og:description" content="'.$this->get_decription().'" />' . "\n";
		}

		if( $this->do_meta()){
			$fbmeta .='<meta property="og:title" content="'.$this->get_wp_title().'" />' . "\n";
			$gpmeta .='<meta itemprop="description" content="'.$this->get_decription().'">' . "\n";
			$fbmeta .='<meta property="og:description" content="'.$this->get_decription().'" />' . "\n";
		}
		

		if( $this->get_share_option('facebook_meta') == 1 )
			echo $fbmeta;
		
		if( $this->get_share_option('google_meta') == 1 )
			echo $gpmeta;

		endif;
	}

	// --------------------------------------------------------------------------


	function render($layout = 'horizontal', $is_preview = false)
	{
	          global $post;
	          /* conditions */
	          $facebook = $this->get_share_option('show_facebook') == 1;
	          $twitter = $this->get_share_option('show_twitter') == 1;
	          $google = $this->get_share_option('show_google') == 1;
	          $pinterest = $this->get_share_option('show_pinterest') == 1;

		

		$output = '';

		$permalink = get_permalink();
		if($is_preview)
			$permalink = 'http://themes.brutaldesign.com';

		//$layout = $this->get_share_option('layout');

	          if( $this->bd_seo_is_on() && $post &&  get_post_meta( $post->ID, 'bd_seo_description', true ) != null){
	          		$title='data-text="'.get_post_meta( $post->ID, 'bd_seo_description', true ).'"';
	          }else{

	            	$title='data-text="'.get_the_title().' | '.get_bloginfo( 'name' ).'"';
	          }

	          if($is_preview)
	          		$title='data-text="Share this Plugin"';

	          	if(is_single())
	          		$output .= '<p class="bd-share-text">'.stripslashes($this->get_share_option('text')).'</p>';

	          $output .= '<div class="bd-share-container '.$layout.'">';

		if($facebook){
			if(!$this->is_bd_framework()) $output .= '<div id="fb-root"></div>';

			if($layout == 'horizontal')
				$facebook_layout = 'data-width="100" data-height="80" data-layout="button_count"';
			else
				$facebook_layout = 'data-width="54" data-height="54" data-layout="box_count"';

			$output .= '<div class="bd-share-facebook">';
			$output .= '<div class="fb-like" data-href="'.$permalink.'" data-send="false" '.$facebook_layout.' data-show-faces="false" data-font="verdana"></div>';
			$output .= '</div>';
		}

		if($twitter){
			$twitter_data_link = 'data-url="'.$permalink.'"';

			$twitter_layout = '';
			if($layout == 'vertical')
				$twitter_layout = ' data-count="vertical"';

			$output .= '<div class="bd-share-twitter">';
			$output .= '<a href="http://twitter.com/share" '.$twitter_data_link.' '.$title.' class="twitter-share-button"'.$twitter_layout.'>Tweet</a>';
			$output .= '</div>';
		}

		if($google){

			if($layout == 'horizontal')
				$google_layout = 'medium';
			else
				$google_layout = 'tall';

			$output .= '<div class="bd-share-google">';
			$output .= '<div class="g-plusone" data-size="'.$google_layout.'" data-href="'.$permalink.'"></div>';
			$output .= '</div>';
		}

		if($pinterest){
			$output .= '<div class="bd-share-pinterest">';
			$output .= '<a href="http://pinterest.com/pin/create/button/?url='.$permalink.'&media='.$this->get_fb_image().'&description='.urlencode($this->get_decription()).'" class="pin-it-button" count-layout="'.$layout.'"><img border="0" src="//assets.pinterest.com/images/PinExt.png" title="Pin It" /></a>';
			$output .= '</div>';
		}

		$output .= '<div style="clear:both; float:none"></div></div>';
	                    
		if( $facebook || $twitter || $google || $pinterest ) //main condition
			return '<div style="margin:0; padding:0; height:0; width:0; clear:both"></div>'.$output;
	      
	} // end function

	// --------------------------------------------------------------------------

	function render_mobile( $text )
	{
		global $post;
		/* conditions */
		$facebook = $this->get_share_option('show_facebook') == 1;
		$twitter = $this->get_share_option('show_twitter') == 1;
		$google = $this->get_share_option('show_google') == 1;
		$pinterest = $this->get_share_option('show_pinterest') == 1;
		
		$img_path = BD_THEME_URL . 'images/share/';
		$desc = $this->get_decription();
		$output = '';

		$permalink = get_permalink();
		$share_title = get_the_title().' | '.get_bloginfo( 'name' );

		if($text)
			$display_text = __('Share : ', 'bd');
		else
			$display_text = '';

		$output .= '<div style="clear:both"></div><div class="bd-share-mobile">' . $display_text . ' ';

		if($facebook){
			$fb_link = 'http://www.facebook.com/sharer.php?u=' . $permalink . '&t='.urlencode($share_title).'';
			$output .= '<a href="' . $fb_link . '">';
			$output .= '<img src="' . $img_path . 'facebook.png" alt="facebook">';
			$output .= '</a>';
		}

		if($twitter){
			$tw_link = 'http://twitter.com/home?status='. urlencode($share_title.' - ').$permalink;
			$output .= '<a href="' . $tw_link . '">';
			$output .= '<img src="' . $img_path . 'twitter.png" alt="twitter">';
			$output .= '</a>';
		}

		if($google){
			$gg_link = 'https://plus.google.com/share?url=' . urlencode($permalink) . '';
			$output .= '<a href="' . $gg_link . '">';
			$output .= '<img src="' . $img_path . 'googleplus.png" alt="google plus">';
			$output .= '</a>';
		}

		if($pinterest){
			$pin_link = 'http://pinterest.com/pin/create/button/?url=' .$permalink. '&media=' .$this->get_fb_image(). '&description='.$desc;
			$output .= '<div class="bd-pin" ><a count-layout="none" href="' . $pin_link . '">';
			$output .= '<img src="' . $img_path . 'pinterest.png" alt="pinterest">';
			$output .= '</a></div>';
		}

		$output .= '</div><div style="clear:both"></div>';

		if( $facebook || $twitter || $google || $pinterest )
			return $output;
	}

	// --------------------------------------------------------------------------


} // end class
global $bd_share;
$bd_share = new BdShare;

function bd_is_share()
{
	global $options;
	$o = get_option('bd_share_settings');

	if( $o ){
		if( isset($o['show_twitter']) || isset($o['show_facebook']) || isset($o['show_google'])  || isset($o['show_pinterest']) ){
			if( $o['show_twitter'] == 1 || $o['show_facebook'] == 1 || $o['show_google'] == 1 || $o['show_pinterest'] == 1 )
				return true;
		}
	}

}

function bd_share($layout){
	global $bd_share;
	echo $bd_share->render($layout);
}

function bd_share_mobile($text = true){
	global $bd_share;
	echo $bd_share->render_mobile($text);
}
?>
