<?php
/*-----------------------------------------------------------------------------------*/
/*  Template tags that we will use in loop-post.php
/*-----------------------------------------------------------------------------------*/

/* *
* Post Title
*/
if ( ! function_exists( 'bd_post_title' ) ) :

function bd_post_title()
{
	if(is_single()):
	?>
	<h1 class="entry-title"><?php the_title(); ?></h1>
	<?php else: ?>
		<h2 class="entry-title">
			<a class="entry-link" rel="bookmark" title="<?php printf(__('Permanent Link to %s', 'bd'), get_the_title()); ?>" href="<?php echo esc_url( get_permalink() ); ?>">
				<?php the_title(); ?>
			</a>
		</h2>
	<?php 
	endif;
}
endif;

/**
* Post Content
*/
if ( ! function_exists( 'bd_post_text' ) ) :
	
function bd_post_text()
{

	if( bd_get_option('excerpt_type') == 'manual' ){
		the_content( bd_get_more_link_text() );

	}elseif( bd_get_option('excerpt_type') == 'auto' ){
		
		if( ! is_single())
			the_excerpt();
		else
			the_content();
	}
}
endif;



/**
* Single Post Page navigation
*/
if ( ! function_exists( 'bd_single_post_nav' ) ) :

function bd_single_post_nav()
{
?>
	<div class="post-nav clearfix">
		<p class="left" style="margin-top:5px; margin-bottom:8px">
			<?php next_post_link('%link',"&lsaquo; %title"); ?>
		</p>
		<p class="right" style="margin-top:5px; margin-bottom:8px">
			<?php previous_post_link('%link',"%title &rsaquo;"); ?>
		</p>
	</div>
<?php
}
endif;

/**
* Comments function
*/
if ( ! function_exists( 'bd_comment' ) ) :

function bd_comment( $comment, $args, $depth )
{
	$GLOBALS['comment'] = $comment;

	$type = $comment->comment_type;

	if( $type == 'pingback' ):

	elseif( $type == 'trackback' ):
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'bd' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'bd' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
	else :
	?>
	<li <?php comment_class('comment'); ?> id="li-comment-<?php comment_ID(); ?>">

		<article id="comment-<?php comment_ID(); ?>" class="description">
			<?php echo get_avatar( $comment, 80 ); ?>
			<div class="comment-info">

			<?php
			/* translators: 1: comment author, 2: date and time */
			printf( __( '%1$s <span class="smooth">on</span> %2$s ', 'bd' ),
			sprintf( '<span class="comment-author">%s</span>', get_comment_author_link() ),
			sprintf( '<span class="comment-time smooth"><time pubdate datetime="%2$s">%3$s</time></span>',
			    esc_url( get_comment_link( $comment->comment_ID ) ),
			    get_comment_time( 'c' ),
			    /* translators: 1: date, 2: time */
			    sprintf( __( '%1$s at %2$s', 'bd' ), get_comment_date(), get_comment_time() )
			)
			);
			?>

			<?php if ( $comment->comment_approved == '0' ) : ?>
			<br>
			<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'bd' ); ?></em>
			<?php endif; ?>

			</div>

			<div class="comment-content"><?php comment_text(); ?></div>
			<div class="clear"></div>
			
			<div class="reply-link right">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'bd' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
			<?php edit_comment_link( __( 'Edit', 'bd' ), '<span class="edit-link admin-link">', '</span>' ); ?>
			<div class="clear"></div>
		
		</article><!-- #comment-## -->

		<div class="clear"></div>

		<hr>
	<?php endif;
}
endif; // ends check for bd_comment()



/**
* Get blog links
*/
if ( ! function_exists( 'bd_post_meta' ) ) :

function bd_post_meta()
{
	global $options, $post;
	$permalink = get_option('permalink_structure')!='';
	
	
	/* Comment
	---------------------*/
	$num_comments = get_comments_number();

	if ( comments_open() ){
		if($num_comments == 0){
			$comments = __('No Comment', 'bd');
		}

		elseif($num_comments > 1){
			$comments = $num_comments.' '. __('Comments', 'bd');
		
		}else{
			$comments = '1 '. __('Comment', 'bd');
		}

		if(is_single()){
			$print_comments = '  <span class="icon-comment"></span><a title="'.__('Comment on', 'bd').' ' . get_the_title().'" class="scroll" href="#comments">'. $comments.'</a>';
		}else{
			$print_comments = '  <span class="icon-comment"></span><a title="'.__('Comment on', 'bd').' ' . get_the_title().'" href="'.esc_url(get_comments_link()).'">'. $comments.'</a>';
		}
	}
	else{ 
		$print_comments = ''; 
		// Uncomment the line below to display a text when comment are off
		//$print_comments =  ''.__('Coments are off', 'bd'); 
	}


	/* Date
	---------------------*/
	$date = get_the_date( get_option('date_format') );

	$html ='<div class="entry-meta">
		<span class="meta published"><span class="icon-date"></span>'.$date.'</span>';

	// Post author
	if ( 'post' == get_post_type() && is_multi_author() ) {
		$html .= sprintf( '<span class="meta author author vcard"><span class="icon-author"></span><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_attr( sprintf( __( 'View all posts by %s', 'wolf' ), get_the_author() ) ),
			get_the_author()
		);
	}

	$html .='<span class="meta comment-count">'.$print_comments.'</span>';
	
	$html .='</div>';

	echo $html;   
}
endif; // end check for bd_get_post_links


/**
* Category list and tags for the blog posts
*/
if ( ! function_exists( 'bd_post_category_and_tags' ) ) :

function bd_post_category_and_tags()
{
	$html ='<div class="entry-meta">';
	$html .='<span class="meta entry-categories"><span class="icon-category"></span>'.get_the_category_list(', ', '').'</span>';    
	$html .= get_the_tag_list('<span class="meta entry-tags"><span class="icon-tags"></span>',', ','</span>');
	$html .='</div>';
	echo $html;
}
endif;


/**
* Taxonomy for custom post types
*/
if ( ! function_exists( 'bd_taxonomy' ) ) :

function bd_taxonomy($term)
{
	global $post;
	$html = get_the_term_list( $post->ID, $term, '<span class="blog-taxonomy-list">', ', ', '</span>' );
	echo $html;
}
endif;
?>
