<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Flickr Widget
	Plugin URI: http://themes.brutaldesign.com
	Description: A widget that displays your Flickr Photos
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_flickr_init');

function bd_flickr_init(){

	register_widget('bd_flickr_widget');
	
}

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class bd_flickr_widget extends WP_Widget {

	/*-----------------------------------------------------------------------------------*/
	/*	Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_flickr_widget() {
    		// Widget settings
		$ops = array(
			'classname' => 'flickr-widget', 
			'description' => __('Display your last flickr photos', 'bd'));

		// Create the widget
		$this->WP_Widget('flickr-widget', 'Flickr', $ops);
	}


	/*-----------------------------------------------------------------------------------*/
	/*	Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget( $args, $instance ) {
 		
 		extract($args);
		$title = apply_filters('widget_title', $instance['title']);
		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		$flickrid = $instance['flickrid'];
		bd_flickr($instance['flickrid'], $instance['count']); 
		echo $after_widget;

  	}

	/*-----------------------------------------------------------------------------------*/
	/*	Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance) {

		$instance = $old_instance;

		$instance['title'] = strip_tags( $new_instance['title']);
		$instance['count'] = strip_tags( $new_instance['count']);
		$instance['flickrid'] = strip_tags( $new_instance['flickrid']);

		return $instance;

	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form( $instance ) {
		$defaults = array('title' => 'Flickr', 'flickrid' => 'flickrid', 'count' => 12);
		$instance = wp_parse_args((array) $instance, $defaults);
		?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd'); ?>:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('flickrid'); ?>"><?php _e('Flickr user ID', 'bd'); ?>:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('flickrid'); ?>" name="<?php echo $this->get_field_name('flickrid'); ?>" value="<?php echo $instance['flickrid']; ?>" />
	 		<small><?php printf( __('Don\'t know your ID? Head on over %s', 'bd') , '<a href="http://idgettr.com" target="_blank">idgettr</a>' ); ?></small>
	 	</p>
	 	<p>
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Number of photos', 'bd'); ?>:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" value="<?php echo $instance['count']; ?>" />
		</p>

		<?php

	}

}
	
/*-----------------------------------------------------------------------------------*/
/*	Flickr Function
/*-----------------------------------------------------------------------------------*/

function bd_flickr_error(){

	$output = '<p>'.__('Sorry, could not load flickr images.', 'bd').'</p>';
	if ( is_user_logged_in() )
		$output = '<p>'.__('Sorry, could not load flickr images. Please double check your flickr ID.', 'bd').'</p>';

	return $output;

}



function bd_get_flickr_xml($flickrid){

	$trans_key = 'bd_flickr_'.$flickrid;
	$rss_url = "http://api.flickr.com/services/feeds/photos_public.gne?id=".$flickrid."&lang=en-us&format=rss_200";

	if ( false === ( $cached_xml = get_transient( $trans_key ) ) ){
		if( function_exists('curl_init') ){
			$c = curl_init($rss_url);
			curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($c, CURLOPT_HEADER, 0);
			curl_setopt($c, CURLOPT_TIMEOUT, 10);
			$xml = curl_exec($c);
			curl_close($c);
		} else {
			$xml = file_get_contents($rss_url);
		}
		
		if ($xml){
			set_transient( $trans_key, $xml, BD_CACHE_DURATION ); 
		}
	}else{
		$xml = $cached_xml;
	}
		
	return @simplexml_load_string($xml);

}


function bd_flickr($flickrid, $count){

	if( bd_get_flickr_xml($flickrid) ){
		$xml = bd_get_flickr_xml($flickrid);
		$regx = '/src="([^"]*)"/i';
		$matches = array();
			echo '<ul class="flickr-list clearfix">';
			for ($i=0; $i<$count; $i++){
				if($xml->channel->item[$i]){
					preg_match( $regx, $xml->channel->item[$i]->description, $matches );
					$img_url = str_replace("_m.jpg", "_s.jpg", $matches[1]);
					echo '<li>
					<a href="' . $xml->channel->item[$i]->link . '" target="_blank">
						<img src="'.$img_url.'" alt="'. $xml->channel->item[$i]->title .'" title="'. $xml->channel->item[$i]->title .'">
					</a>
					</li>';
				}
			}
			echo '</ul>';
	}else{
		echo bd_flickr_error();
          }	
}

?>