<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Last Photos Widget
	Plugin URI: http://themes.brutaldesign.com
	Description: Display your last uploaded photos
	Version: 1.2
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_last_photos_init');

function bd_last_photos_init(){

	register_widget('bd_last_photos_widget');
	
}

/*-----------------------------------------------------------------------------------*/
/*  Widget Class
/*-----------------------------------------------------------------------------------*/
class bd_last_photos_widget extends WP_Widget {

	/*-----------------------------------------------------------------------------------*/
	/*  Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_last_photos_widget(){

		// Widget settings
		$ops = array('classname' => 'widget_last_photos', 'description' => __('Display your last pics', 'bd'));

		// Create the widget
		$this->WP_Widget('widget_last_photos', 'Last Photos', $ops);
		
	}

	/*-----------------------------------------------------------------------------------*/
	/*  Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget($args, $instance){
		
		extract($args);
		$title = apply_filters('widget_title', $instance['title']);
		$desc = $instance['desc'];
		$layout = $instance['layout'];
		$timeout = $instance['timeout'];
		$slideshow = false;
		if($layout == '1')
			$slideshow = true;

		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		if (!empty($desc)){
			echo '<p>';
			echo $desc;
			echo '</p>';
		}
		bd_last_photos($instance['count'], $slideshow, $timeout);
		echo $after_widget;
	
	}

	/*-----------------------------------------------------------------------------------*/
	/*  Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance){
		
		$instance = $old_instance;
		$instance['title'] = $new_instance['title'];
		$instance['desc'] = $new_instance['desc'];
		$instance['count'] = $new_instance['count'];
		$instance['layout'] = $new_instance['layout'];
		$instance['timeout'] = $new_instance['timeout'];
		if($instance['timeout']==0 || $instance['timeout']=='') $instance['timeout'] = 3500;

		return $instance;
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form($instance){

			// Set up some default widget settings
			$defaults = array(
				'title' => __('Last Photos', 'bd'), 
				'desc' => '',
				'count' => 12, 
				'layout' => '0',
				'timeout' => '3500'
				);
			$instance = wp_parse_args((array) $instance, $defaults);

		?>
		<script type="text/javascript">
			jQuery(function($){
				var select = $('.bd-last-photos-layout-select');
				select.live('change', function(){
					var val = $(this).val();
					if(val == '1'){
						$(this).parent().next().show();
					}else{
						$(this).parent().next().hide();
					}
				});
			});
		</script>
		
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd' ); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('desc'); ?>"><?php _e('Optional Text', 'bd'); ?>:</label>
			<textarea class="widefat"  id="<?php echo $this->get_field_id('desc'); ?>" name="<?php echo $this->get_field_name('desc'); ?>" ><?php echo $instance['desc']; ?></textarea>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Count', 'bd' ); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" value="<?php echo $instance['count']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('layout'); ?>"><?php _e('Display', 'bd'); ?>:</label>
			<select class="bd-last-photos-layout-select"  name="<?php echo $this->get_field_name('layout'); ?>" id="<?php echo $this->get_field_id('layout'); ?>">
				<option value="0" <?php if($instance['layout'] == '0') echo 'selected="selected"'; ?>><?php _e('thumbnails', 'bd'); ?></option>
				<option value="1" <?php if($instance['layout'] == '1') echo 'selected="selected"'; ?>><?php _e('slideshow', 'bd'); ?></option>
			</select>
		</p>
		<p <?php if($instance['layout'] == '0' )  echo 'style="display:none"';  ?>>
			<label for="<?php echo $this->get_field_id('timeout'); ?>"><?php _e('Time between animation in milliseconds', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('timeout'); ?>" name="<?php echo $this->get_field_name('timeout'); ?>" value="<?php echo $instance['timeout']; ?>">
		</p>
		<?php
	}

	

}

/*-----------------------------------------------------------------------------------*/
/*	Video Function
/*-----------------------------------------------------------------------------------*/
function bd_last_photos($count = 12, $slideshow = false, $timeout = 3500){
	global $wpdb;
	$grid = array();
	$query = new WP_Query( array( 
		'post_type' => 'gallery', 
		'posts_per_page' => -1 ) 
	);
	if( $query->have_posts() ){
		while($query->have_posts()){
			$query->the_post();

			$content = get_the_content();
			$string = preg_match('/ids=\"(.*)\"/i', $content, $result);
			

			if( isset($result[1]) ){
				$string = str_replace(' ', '', $result[1]);
				$image_ids = explode( ',', $string );

				foreach($image_ids as $image_id){
					$img_src_mini = wp_get_attachment_image_src( $image_id, 'photo-widget-thumb'); 
					$img_src_slide = wp_get_attachment_image_src( $image_id, 'photo-widget-slide'); 
					$img_src_full = wp_get_attachment_image_src( $image_id, 'full-size'); 
					$grid[] = array(
						'thumb' => $img_src_mini[0],
						'slide' =>  $img_src_slide[0],
						'full' =>$img_src_full[0],
					);
				}
			}
		}

		if( count($grid) < $count && $grid != array() )
			$count = count($grid);

		if($slideshow){
			$output = '';
			wp_enqueue_script('cycle', BD_THEME_URL. 'includes/widgets/js/jquery.cycle.lite.js', 'jquery', '1.3.2');
			$output .= '<script type="text/javascript">
			jQuery(document).ready(function($) {
			    $(".slidephoto-container").cycle({
					fx: "fade",
					timeout : '.$timeout.'
				});
			});

			</script>';
			$output .= '<div class="slidephoto-container clearfix">';
			$fluid_fix = ' slidephoto-fluid-fix';

			for($i=0; $i<$count; $i++){
		
				$output .= '<div class="slidephoto';
				if( $i == 0 ) $output .= $fluid_fix;
				$output .= '">
				<a rel="last-photos" class="fancybox" href="'.$grid[$i]['full'].'">
				<img src="'.$grid[$i]['slide'].'"></a>
				</div>';
			}
			$output .= '</div>';

			echo $output;

		}else{
			for($i = 0; $i < $count; $i++){
				echo '<a rel="last-photos" href="'.$grid[$i]['full'].'" class="last-photos-thumbnails fancybox"><img src="'.$grid[$i]['thumb'].'"></a>';
			}
			echo '<div class="clear"></div>';
		}
	

	}else{
		echo "<p>";
		_e('No photo uploaded yet.', 'bd');
		echo "</p>";
	}
}        
?>