<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Custom Comments Widget
	Plugin URI: http://themes.brutaldesign.com
	Description: A widget that displays the latest comment with the user avatar
	Version: 1.0
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_recent_comments_init');

function bd_recent_comments_init(){

	register_widget('bd_recent_comments_widget');
	
}


/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class bd_recent_comments_widget extends WP_Widget {

	/*-----------------------------------------------------------------------------------*/
	/*	Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_recent_comments_widget(){

		// Widget settings
		$ops = array('classname' => 'widget_reactions', 'description' => __('Custom Recent Comments', 'bd'));

		// Create the widget
		$this->WP_Widget('widget_reactions', __('Recent Comments with avatars', 'bd'), $ops);
		
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget($args, $instance){
		
		extract($args);
		
		$title = apply_filters('widget_title', $instance['title']);
		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		bd_recent_comments($instance['count']);
		echo $after_widget;
	
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance){
		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];
		$instance['count'] = $new_instance['count'];

		return $instance;
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form($instance){

			// Set up some default widget settings
			$defaults = array('title' => 'Comments', 'count' => 3);
			$instance = wp_parse_args((array) $instance, $defaults);

		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Number of comments', 'bd' ); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" value="<?php echo $instance['count']; ?>">
		</p>
		
		<?php
	}

	

}

 
	/*-----------------------------------------------------------------------------------*/
	/*	Comments functions
	/*-----------------------------------------------------------------------------------*/
	function bd_recent_comments($nbr_comments = 6, $comment_len = 60) {
	    	global $wpdb;

	    	$comments = get_comments( apply_filters( 'widget_comments_args', array( 'number' => $nbr_comments, 'status' => 'approve', 'post_status' => 'publish' ) ) );

		if ($comments) {
			echo "<div class=\"widget-thumbnails-list\">";
			foreach ($comments as $comment) {
				$comment_text = bd_sample($comment->comment_content, $comment_len);
				$comment_img_title_attr = bd_sample($comment->comment_content, 250);
				$comment_post_title = bd_sample($comment->post_title, 35);
				ob_start();
				?>
				<article class="widget_reaction">
					<a href="<?php echo esc_url(get_permalink( $comment->comment_post_ID )) . '#comment-' . $comment->comment_ID; ?>" class="widget-thumb-link">
						<?php echo get_avatar($comment->comment_author_email); ?>
					</a>
					<a href="<?php echo esc_url(get_permalink( $comment->comment_post_ID )) . '#comment-' . $comment->comment_ID; ?>">
						<?php echo bd_get_author($comment); ?></a> <?php _e('said', 'bd'); ?>
					<strong>
						<a title="<?php echo $comment_img_title_attr; ?>" href="<?php echo esc_url(get_permalink( $comment->comment_post_ID )) . '#comment-' . $comment->comment_ID; ?>">
							"<?php echo $comment_text; ?>"
						</a>
					</strong> <?php _e('on', 'bd'); ?> <a href="<?php echo esc_url(get_permalink( $comment->comment_post_ID )) . '#comment-' . $comment->comment_ID; ?>" title="<?php _e('Read the comment', 'bd'); ?>">
						<?php echo $comment_post_title; ?>
					</a>
					<div class="clear"></div>
				</article>
				<?php
				ob_end_flush();
			}
			echo "</div>";
		} else {
			echo __('No comment', 'bd').'';
		}
	}


	/**
	* Get the author name
	**/
	function bd_get_author($comment) {
		$author ='';

		if ( empty($comment->comment_author) )
			$author = __('Anonymous', 'bd');
		else
			$author = $comment->comment_author;

		return $author;
	}
?>