<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Recent Posts Widget with Thumbnails
	Plugin URI: http://themes.brutaldesign.com
	Description: A widget that displays your recent posts with thumbnails
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_recent_posts_init');

function bd_recent_posts_init(){

	register_widget('bd_recent_posts_widget');
	
}

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class bd_recent_posts_widget extends WP_Widget {


	/*-----------------------------------------------------------------------------------*/
	/*	Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_recent_posts_widget(){

		// Widget settings
		$ops = array(
			'classname' => 'post-types-widget', 
			'description' => 'Display your recent posts: recents or populars, with or without thumbnail');

		// Create the widget
		$this->WP_Widget('widget_recent_post_w_thumbnails', 'Recent Posts with Thumbnails', $ops);
		
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget($args, $instance){
		
		extract($args);
		
		$title = apply_filters('widget_title', $instance['title']);
		$count = $instance['count'];
		
		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		bd_post_types_widget($count, $instance['post-type'], $instance['display'], $instance['category']);
		echo $after_widget;
	
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance){
		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];
		$instance['count'] = $new_instance['count'];
		$instance['type'] = $new_instance['type'];
		$instance['display'] = $new_instance['display'];
		$instance['post-type'] = $new_instance['post-type'];
		$instance['category'] = $new_instance['category'];

		return $instance;
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form($instance){
		global $BD_theme;
			// Set up some default widget settings
			$defaults = array('title' => 'Recent Posts', 'post-type' => 'post', 'count' => 3, 'type' => 'thumbnail', 'display' => 'recent', 'category' => 'all');
			$instance = wp_parse_args((array) $instance, $defaults);

			$post_types = array();
			if(isset($BD_theme['post-types']) && is_array($BD_theme['post-types']))
				$post_types = $BD_theme['post-types'];

				unset($post_types['show']);
		?>
		<script type="text/javascript">
			jQuery(function($){
				var select = $('.bd-post-type-select');
				$(document).on('change', '.bd-post-type-select', function(){
					var val = $(this).val();
					var opt = $(this).parent().parent().find('.widget-post-type-opt-cat');
					if(val == 'post'){
						opt.show();
					}
					if(val != 'post'){
						opt.hide();
					}

					var opt_display = $(this).parent().parent().find('.widget-post-type-opt-display');

					if(val == 'post' || val == 'review'){
						opt_display.show();
					}
					if(val != 'post' && val != 'review'){
						opt_display.hide();
					}
				});
			});
		</script>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('post-type'); ?>"><?php _e('Post Type', 'bd' ); ?>:</label><br>
			<select class="bd-post-type-select" name="<?php echo $this->get_field_name('post-type'); ?>" id="<?php echo $this->get_field_id('post-type'); ?>">
				<option value="post" <?php if($instance['post-type']=='post') echo 'selected="selected"'; ?>>Post</option>
			<?php   
			foreach($post_types as $k => $v): 
				$id = sanitize_title($k);
			
				$s = substr($id, -1);
				
				if($s == 's')
					$id = substr( $id , 0, -1 );

				$slug = $id;
				if(isset($v['slug']))
					$slug = sanitize_title($v['slug']);

				
				$singular = ucfirst( str_replace( array('-', '_'), ' ', $id) );
				
				if(isset($v['singular']))
					$singular = ucfirst( str_replace( array('-', '_'), ' ', $v['singular']) );
				
				
				$plural = $singular.'s';
				if(isset($v['plural']))
					$plural = ucfirst( str_replace( array('-', '_'), ' ', $v['plural']) );


				$menu_name = ucfirst($plural);
				if(isset($v['menu_name']))
					$menu_name = ucfirst($v['menu_name']);
			?>
				<option value="<?php echo $id; ?>" <?php if($instance['post-type']==$id) echo 'selected="selected"'; ?>><?php echo $menu_name; ?></option>
			<?php endforeach ; ?>
				
			</select>
		</p>
		
		<div class="widget-post-type-opt-cat" <?php if($instance['post-type'] != 'post' )  echo 'style="display:none"';  ?>>
			<p>
				<label for="<?php echo $this->get_field_id('category'); ?>"><?php _e('Post Category', 'bd' ); ?>:</label><br>
				<select  name="<?php echo $this->get_field_name('category'); ?>" id="<?php echo $this->get_field_id('category'); ?>">
					<?php 
					$bd_categories = get_categories();
					$bd_categories_tab = array();
					foreach($bd_categories as $category){
						$bd_categories_tab['all'] = 'All';
						$bd_categories_tab[$category->cat_ID] = $category->name;
					} 
			
					foreach($bd_categories_tab as $k => $v):?>
			
					<option value="<?php echo $k; ?>" <?php if($instance['category']==$k) echo 'selected="selected"'; ?>><?php echo $v; ?></option>
					<?php endforeach; ?>
					
					
				</select>
			</p>
		</div>
		<div class="widget-post-type-opt-display" <?php if( $instance['post-type'] != 'post' && $instance['post-type'] != 'review' )  echo 'style="display:none"';  ?>>
			<p>
				<label for="<?php echo $this->get_field_id('display'); ?>"><?php _e('Display', 'bd'); ?>:</label><br>
				<select name="<?php echo $this->get_field_name('display'); ?>" id="<?php echo $this->get_field_id('display'); ?>">
					<option <?php if($instance['display']=='recent') echo 'selected="selected"'; ?>><?php _e('recent', 'bd'); ?></option>
					<option <?php if($instance['display']=='popular') echo 'selected="selected"'; ?>><?php _e('popular', 'bd'); ?></option>
				</select>
			</p>
		</div>
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Count', 'bd'); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" value="<?php echo $instance['count']; ?>">
		</p>
		<?php
	}

	

}
		
	/*-----------------------------------------------------------------------------------*/
	/*	Function
	/*-----------------------------------------------------------------------------------*/
	function bd_post_types_widget($count=5, $post_type, $display, $category){
		global $wpdb, $BD_theme;
		$do_not_duplicate = array();

		
		if(is_single()){
			global $wp_query;
			$do_not_duplicate[] = $wp_query->post->ID;
		}

		$args = array( 
				'post_type' => array($post_type) ,
				'posts_per_page' => $count,
				'meta_key'    => '_thumbnail_id',
			);


		if( $display == 'popular' ){
			
			$args['orderby'] = 'comment_count';
		}
		

		if( $post_type == 'post' && $category!='all' ){
			$args['category__in'] = $category;
		}

		if(is_single() && $post_type == 'post'){
			$args['post__not_in'] = $do_not_duplicate;
		}

		$loop = new WP_Query($args);
		
		if($loop->have_posts()): 
		
		echo '<div class="widget-thumbnails-list clearfix widget-post-type-'. $post_type .'">';
			
			while ($loop->have_posts()) : $loop->the_post();
			$rating = get_post_meta(get_the_ID(), 'bd_review_rating', true);
			?>
				<article>
					<a href="<?php esc_url(the_permalink()); ?>" class="widget-thumb-link">
						<?php the_post_thumbnail( 'mini', array( 'title' => '') ) ; ?>
					</a>
					<span class="entry-title"><a href="<?php esc_url(the_permalink()); ?>" title="<?php printf(__('Permanent Link to %s', 'bd'), get_the_title()); ?>"><?php echo bd_sample(get_the_title(), 40); ?></a></span>
						<br>
					<?php if( $post_type != 'review' ): ?>
					<small class="time"><?php echo get_the_date( get_option('date_format') ); ?></small><br>
					<?php endif; ?>
					<small class="comment-count"><?php bd_comment_number(); ?></small>
					<br><?php if(function_exists('bd_rating')) echo bd_rating( $rating, true ); ?>
					<div class="clear"></div>
				</article><?php
		endwhile;
		wp_reset_query();
		wp_reset_postdata();
		?></div><?php 
		endif;
	}        

?>