<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Upcoming Shows Widget
	Plugin URI: http://themes.brutaldesign.com
	Description: Display your upcoming shows dates
	Version: 1.1
	Author: BrutalDesign
	Author URI: http://themes.brutaldesign.com

-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init', 'bd_upcoming_shows_init');

function bd_upcoming_shows_init(){

	register_widget('bd_upcoming_shows_widget');
	
}

/*-----------------------------------------------------------------------------------*/
/*  Widget Class
/*-----------------------------------------------------------------------------------*/
class bd_upcoming_shows_widget extends WP_Widget {

	/*-----------------------------------------------------------------------------------*/
	/*  Widget Setup
	/*-----------------------------------------------------------------------------------*/
	function bd_upcoming_shows_widget(){

		// Widget settings
		$ops = array('classname' => 'widget_upcoming_shows', 'description' => __('Display your tour dates', 'bd'));

		// Create the widget
		$this->WP_Widget('widget_upcoming_shows', 'Upcoming Shows', $ops);
		
	}

	/*-----------------------------------------------------------------------------------*/
	/*  Display Widget
	/*-----------------------------------------------------------------------------------*/
	function widget($args, $instance){
		
		extract($args);
		
		$title = apply_filters('widget_title', $instance['title']);
		$desc = '<p>'.$instance['desc'].'</p>';
		echo $before_widget;
		if (!empty($title)) echo $before_title . $title . $after_title;
		if($instance['desc']) echo $desc;
		echo bd_upcoming_shows($instance['count']);
		echo $after_widget;
	
	}

	/*-----------------------------------------------------------------------------------*/
	/*  Update Widget
	/*-----------------------------------------------------------------------------------*/
	function update($new_instance, $old_instance){
		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];
		$instance['desc'] = $new_instance['desc'];
		$instance['count'] = $new_instance['count'];

		return $instance;
	}

	/*-----------------------------------------------------------------------------------*/
	/*	Displays the widget settings controls on the widget panel
	/*-----------------------------------------------------------------------------------*/
	function form($instance){

			// Set up some default widget settings
			$defaults = array(
				'title' => 'Upcoming Shows', 
				'count' => 10, 
				'desc' => '');
			$instance = wp_parse_args((array) $instance, $defaults);

		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'bd' ); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('desc'); ?>"><?php _e('Optional Text', 'bd'); ?>:</label>
			<textarea class="widefat"  id="<?php echo $this->get_field_id('desc'); ?>" name="<?php echo $this->get_field_name('desc'); ?>" ><?php echo $instance['desc']; ?></textarea>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('count code', 'bd' ); ?>:</label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" value="<?php echo $instance['count']; ?>">
		</p>
		<?php
	}

	

}

/*-----------------------------------------------------------------------------------*/
/*	Upcoming Shows Function
/*-----------------------------------------------------------------------------------*/
function bd_upcoming_shows($count){

	global $wpdb;
	$output = '';
	$shows = $wpdb->get_results( bd_shows_query(), OBJECT);

	if(count($shows) < $count){
		$count = count($shows);
	}

	if($shows){

		for( $i=0; $i<$count; $i++ ){
			$show = $shows[$i];

			$show_date = bd_custom_date_format(get_post_meta( $show->ID, 'bd_show_date', true ));
			$show_city = get_post_meta( $show->ID, 'bd_show_city', true );
			$show_venue = get_post_meta( $show->ID, 'bd_show_venue', true );
			$show_ticket = get_post_meta( $show->ID, 'bd_show_ticket', true );
			$cancelled = get_post_meta( $show->ID, 'bd_show_cancel', true );
			$soldout = get_post_meta( $show->ID, 'bd_show_soldout', true );
			$free = get_post_meta( $show->ID, 'bd_show_free', true );

			if( !$cancelled && !$soldout && $show_ticket ){
				$show_action = '<br><a target="_blank" href="'.esc_url($show_ticket).'">'.__('BUY TICKET NOW!', 'bd').'</a>';
			}

			elseif( !$cancelled && !$soldout && $free ){

				$show_action = '<span class="smooth">'.__('free', 'bd').'</span>';

			}


			elseif($cancelled){

				$show_action = '<span class="smooth">'.__('cancelled', 'bd').'</span>';

			}

			elseif($soldout){
				$show_action = '<span class="smooth">'.__('sold out!', 'bd').'</span>';
			}	

			
			elseif( !$cancelled && !$soldout && !$show_ticket ){

				$show_action = '';

			}
			
			
			$output .= "<div class=\"bd-show-item\">
				$show_date
				<div class=\"bd-show-details\">
					<strong>$show_city</strong> - $show_venue
					$show_action
				</div>
			</div>";

			if( $i != $count-1 )
				$output .= "<hr style=\"margin:8px 0 12px\">";

			
			

		}

		if( bd_get_shows_url() && !bd_is_page('shows') ){
			$output .= '<p style="margin-top : 1em"><a class="more-link" href="' . bd_get_shows_url() . '">';
			$output .= __('View more dates', 'bd');
			$output .= '</a></p>';
		}

	}else{

		$output .= __('No upcoming show scheduled.', 'bd');

	} // endif shows

	return $output;

}        
?>